#define  USE_HY17M24_2M
/******************************************************************************
 * ADC_Display.c                                                        *
 * -------------------------------------------------------------------------- *
 * Copyright 2019 HYCON Technology                                            *
 * http://www.hycontek.com/                                                   *
 *                                                                            *
 * Program Description:                                                       *
 *                                                                            *
 *     HY17M24                                                       *
 *------------------                                                     *
 *                    |                                                       *
 *             AI0  |->INP                                             *
 *             AI1  |->INN                                             *
 *                    |                                                        *
 *                    |                                                        *
 *         PT3.0  |->SCL                                            *
 *         PT3.1 |->SDA                                           *
 *                    |                                                       *
 *------------------                                                      *
 *                                                                            *
 *                                                                            *
 *                                                                            *
 *                                                                            *
 * For External Input                                                         *
 * IC Body: HY17M24                                                           *

 ******************************************************************************/
/*----------------------------------------------------------------------------*/
/* Includes                                                                   */
/*----------------------------------------------------------------------------*/
#include <SFRType.h>
#include <INT.h>
#include <CLK.h>
#include <RST.h>
#include <I2C.h>
#include <PWR.h>
#include <ADC.h>
#include "seg7.h"
#include "HY2613.h"

/*----------------------------------------------------------------------------*/
/* DEFINITIONS                                                                */
/*----------------------------------------------------------------------------*/
#define I2CBufferSize  11		// HY17M24 max BufferSize 127
#define I2C_WRITE  0x00       // I2C WRITE command
#define I2C_READ   0x01       // I2C READ command
#define I2C_Delay  1000000    //HAO=2MHz, wait 5s
volatile typedef union _Flag
{
 unsigned int  _byte;
  struct
  {
    unsigned b_ADCdone:1;
    unsigned b_TMAdone:1;
    unsigned b_UART_TxDone:1;
    unsigned b_UART_RxDone:1;
    unsigned Reserved:12;
  };
} Flag;

/*----------------------------------------------------------------------------*/
/* Function PROTOTYPES                                                        */
/*----------------------------------------------------------------------------*/
void SysInit(void);
void I2CInit(void);
void Delay(unsigned int num);
void ADCInit(void);
void SendDisplay(signed long  data);
/*----------------------------------------------------------------------------*/
/* Global CONSTANTS                                                           */
/*----------------------------------------------------------------------------*/
signed long  ADC_ISRTemp;
signed long  ADC_ISRTemp_Buffer[8];
signed long  ADCData1;
Flag   Flagbits;
unsigned char I2C_RW;
unsigned char I2C_TARGET;      // Target I2C slave address
unsigned char I2C_Sendbuf[I2CBufferSize];
unsigned char I2C_Recbuf[I2CBufferSize];
unsigned char I2C_EndFlag;
unsigned int I2C_DataTxLen,I2C_DataTxIndex,I2C_DataRxLen,I2C_DataRxIndex;
unsigned char DisplayBuffer[9];
unsigned char i;

/*----------------------------------------------------------------------------*/
/* Main Function                                                              */
/*----------------------------------------------------------------------------*/
void main(void)
{
	SysInit();
	I2CInit();
	ADCInit();
	Flagbits.b_UART_TxDone=1;
	GIE_Enable();
	ClearLCDframe();			//CLR Display

	while(1)
	{
  		Flagbits.b_ADCdone=0;
    	while(Flagbits.b_ADCdone==0);  //until get ADC_ISRTemp
    	Flagbits.b_ADCdone=0;

    	ADC_INT_Disable();
    	SendDisplay(ADC_ISRTemp);
    	ADC_INT_Enable();
	}
}

/*----------------------------------------------------------------------------*/
/* Interrupt Service Routines                                                 */
/*----------------------------------------------------------------------------*/
void ISR(void) __interrupt
{
	if(ADC_INT_IsFlag())
	{
		ADC_INT_ClearFlag();
		ADC_ISRTemp=ADCR; //ADC_GetData();
		Flagbits.b_ADCdone=1;
	}

	if(I2CIF_IsFlag() &&I2C_EndFlag==0)  //Get I2C Interrupt Flag
	{
    	switch(I2C_STAState())
    	{
	      case 0x90:  //MACTFlag+RWFlag
	            //START has been transmitted
	            I2C_SendData(I2C_TARGET);  //Send Slave Address & R/W Bit
	            I2C_Ctrl(0,0,0,0);          //Clear all I2C flag
	            break;

	      case 0x84:  //MACTFlag+ACKFlag
	            //Slave A + W has been transmitted. ACK has been received.
	            I2C_SendData(I2C_Sendbuf[I2C_DataTxIndex++]);  //Send Data to Slave
	            I2C_Ctrl(0,0,0,0);      //Clear all I2C flag
	            break;

	      case 0x80: //MACTFlag
	            //Slave A + W has been transmitted. ACK has been received.
	      		I2C_SendData(I2C_Sendbuf[I2C_DataTxIndex++]);  //Send Data to Slave
	            I2C_Ctrl(0,0,0,0);      //Clear all I2C flag
	            break;

	      case 0x30:

	            I2C_Ctrl(0,0,0,0);      //Clear all I2C flag
	            I2C_EndFlag=1;
	            break;

	      case 0x8C:  //MACTFlag+DFFlag+ACKFlag
	            //DATA has been transmitted and ACK has been received
	            if(I2C_DataTxIndex<I2C_DataTxLen)
	            {
	              I2C_SendData(I2C_Sendbuf[I2C_DataTxIndex++]);  //Send Data to Slave
	              I2C_Ctrl(0,0,0,0);    // Clear all I2C flag
	            }
	            else
	            {
		            if(I2C_RW == I2C_WRITE)
		            {
		            	I2C_Ctrl(0,1,0,0);  //I2C as master sends STOP signal
		            	I2C_EndFlag=1;
		            }
		            else if(I2C_RW == I2C_READ)
		            I2C_Ctrl(1,0,0,0);  //I2C as master sends START signal
		            I2C_DataTxIndex=0;
	            }
	            break;

	      case 0x88:  //MACTFlag+DFFlag
	            //DATA has been transmitted and NACK has been received
	            I2C_Ctrl(0,1,0,0);    //I2C as master sends STOP signal
	            I2C_DataTxIndex=0;
	            I2C_EndFlag=1;
	            break;

	      case 0xB0:
	            //A repeated START has been transmitted.
	            I2C_SendData(I2C_TARGET | I2C_READ);  //Send Slave Address & R/W Bit
	            I2C_Ctrl(0,0,0,0);    //Clear all I2C flag
	            break;

	      case 0x94:  //MACTFlag+RWFlag+ACKFlag
	            //Slave A + R has been transmitted. ACK has been received.
	            if(I2C_DataRxLen>1)
	            {
	              I2C_Ctrl(0,0,0,1);  //Set ACK bit
	            }else{
	              I2C_Ctrl(0,0,0,0);  //Clear all I2C flag
	            }
	            break;

	      case 0x9C:  //MACTFlag+RWFlag+DFFlag+ACKFlag
	            //Data byte has been received. ACK has been transmitted.
	            I2C_ReceiveDATA(I2C_Recbuf[I2C_DataRxIndex++]);
	            //I2C_Recbuf[I2C_DataRxIndex++]=I2C_ReceiveDATA();
	            if((I2C_DataRxLen-1)>I2C_DataRxIndex)
	            {
	              I2C_Ctrl(0,0,0,1);  //Set ACK bit
	            }
	            else
	            {
	              I2C_Ctrl(0,0,0,0);  //Clear all I2C flag
	            }
	            break;

	      case 0x98:  //MACTFlag+RWFlag+DFFlag
	            //Data byte has been received. NACK has been transmitted.
	            I2C_ReceiveDATA(I2C_Recbuf[I2C_DataRxIndex++]);
	            // I2C_Recbuf[I2C_DataRxIndex++]=I2C_ReceiveDATA();
	            I2C_Ctrl(0,1,0,0);  //I2C as master sends STOP signal
	            I2C_EndFlag=1;
	            break;

	      default:
	            I2C_Ctrl(0,0,0,0);  //Clear all I2C flag
	            I2C_EndFlag=1;
	            break;
    	}
		I2C_I2CINT_CLEAR();		//CLR I2C INT Flag
		I2C_I2CER_CLEAR();		//CLR I2C error Flag
		I2CIF_ClearFlag();				//CLR I2CIF
  	}
  	if(I2CERIF_IsFlag())  //Get I2C Error Interrupt Flag
  	{
	    I2C_EndFlag=1;
		I2C_I2CINT_CLEAR();		//CLR I2C INT Flag
		I2C_I2CER_CLEAR();		//CLR I2C error Flag
		I2CERIF_ClearFlag();		//CLR I2CERIF
	    I2C_Ctrl(0,0,0,0);          //Clear all I2C flag
  	}


}

/*----------------------------------------------------------------------------*/
/* System Init Function                                                          */
/*----------------------------------------------------------------------------*/
void SysInit(void)
{
	//PT1.0 HW Reset Function Ensable
	PT10_HWResetEnable();

	//CPU CLK SELECT
	CLK_CPUCKOpen(HAOM_2MHZ ,OSCS_HAO ,DHS_HSCKDIV1 ,CPUS_DHSCK );  //Please refer to the Datasheet for HAOM center frequency

}

/*----------------------------------------------------------------------------*/
/* ADC Init Function                                                          */
/*----------------------------------------------------------------------------*/
void ADCInit(void)
{
   //==========Setup Power=====================================
  PWR_BGREnable();					//bandgap Vref Enable
  PWR_VDDAOpen(LDOC_2V4);	//VDDA Enable, refer to the Datasheet for LDOC typical voltage
  PWR_LDOMode(LDOM_VDD);
  Delay(500);    //Delay 10ms

    //==========Setup ADC=======================================
 ADC_Open(DADC_DHSCKDIV2,INP_AI0,INN_AI1,VRH_VDDA,VRL_VSS,
 						ADGN_1,VREGN_DIV1,DCSET_P0,OSR_65536,VCMS_REFOint);

  //==========Setup ADC INT======================================
  ADC_INT_ClearFlag();      //Clear ADIF
  ADC_INT_Enable();   //ADC INT Enable
  ADC_CMFREnable();     //CMFR=1, Comb Filter Reset

}

/*----------------------------------------------------------------------------*/
/*		      	Send ADC Data to Display								    */
/*----------------------------------------------------------------------------*/
void SendDisplay(signed long  data)
{
	unsigned int num;
    //display range +8388607~-8388608 (dec)
	ADCData1=data;
	if((ADCData1<0)||(ADCData1>0x80000000))  // plus-minus sign judgment
	{
		ADCData1=~ADCData1;
		ADCData1++;
		DisplayBuffer[6]=S_Minus;			// "-"
	}
	else
	{
		DisplayBuffer[6]=0;
	}
	DisplayBuffer[0]=seg[(ADCData1 /1000000)];  //ten thousand
	ADCData1=ADCData1%1000000;
	DisplayBuffer[1]=seg[(ADCData1 /100000)] ;  //thousand
	ADCData1=ADCData1%100000;
	DisplayBuffer[2]=seg[(ADCData1 /10000)] ;  //hundred
	ADCData1=ADCData1%10000;
	DisplayBuffer[3]=seg[(ADCData1 /1000)] ;  //ten
	ADCData1=ADCData1%1000;
	DisplayBuffer[4]=seg[(ADCData1 /100)] ;  //unit
	ADCData1=ADCData1%100;
	DisplayBuffer[5]=seg[(ADCData1 /10)] ;  //unit
//	ADCData1=ADCData1%10;

	DisplayBuffer[7]=0x00;
	DisplayBuffer[8]=0x00;
	RAM2LCD(DisplayBuffer,9);
	for(num=10000;num>0;num--)	__asm__("NOP");
}

/*----------------------------------------------------------------------------*/
/* I2C Init Function                                                          */
/*----------------------------------------------------------------------------*/
void I2CInit(void)
{
	I2C_Open(50);		//I2C Open

	I2C_SetIOPin(2);	// SCL-> PT3.0  SDA->PT3.1

	I2CIE_Enable();
	I2CERIE_Enable();
}

/*----------------------------------------------------------------------------*/
/* Software Delay Subroutines                                                 */
/*----------------------------------------------------------------------------*/
void Delay(unsigned int num)
{
	for(;num>0;num--)
    __asm__("NOP");
}

/*----------------------------------------------------------------------------*/
/* End Of File                                                                */
/*----------------------------------------------------------------------------*/
