#define  USE_HY17M24_2M
/*********************************************************************
 * DrvHY2613.c
 * -------------------------------------------------------------------
 * Copyright 2019 HYCON Technology
 * http://www.hycontek.com/
 *
 * Release
 *     2019
 *
 **********************************************************************/
/*----------------------------------------------------------------------------*/
/* Includes                                                                   */
/*----------------------------------------------------------------------------*/
#include <hy17m24sfr.h>
#include <I2C.h>
#include "seg7.h"
#include "HY2613.h"

/*----------------------------------------------------------------------------*/
/* DEFINITIONS                                                                */
/*----------------------------------------------------------------------------*/

#define I2CBufferSize  11	// HY17M24 max BufferSize 127
#define I2C_WRITE  0x00       // I2C WRITE command
#define I2C_READ   0x01       // I2C READ command
/*----------------------------------------------------------------------------*/
/* Global CONSTANTS                                                           */
/*----------------------------------------------------------------------------*/
extern unsigned char I2C_RW;
extern unsigned char I2C_TARGET;   // Target I2C slave address
extern unsigned char I2C_Sendbuf[I2CBufferSize];
extern unsigned char I2C_Recbuf[I2CBufferSize];
extern unsigned int I2C_DataTxLen,I2C_DataTxIndex,I2C_DataRxLen,I2C_DataRxIndex;
extern unsigned char I2C_EndFlag;
extern unsigned char DisplayBuffer[9];
const unsigned char seg[]={
         seg_a | seg_b | seg_c | seg_d | seg_e | seg_f, // char "0"
         seg_b | seg_c,                         // char "1"
         seg_a | seg_b | seg_d | seg_e | seg_g,       // char "2"
         seg_a | seg_b | seg_c | seg_d | seg_g,       // char "3"
         seg_b | seg_c | seg_f | seg_g,             // char "4"
         seg_a | seg_c | seg_d | seg_f | seg_g,       // char "5"
         seg_a | seg_c | seg_d | seg_e | seg_f | seg_g, // char "6"
         seg_a | seg_b | seg_c,                  // char "7"
         seg_a | seg_b | seg_c | seg_d | seg_e | seg_f | seg_g,  // char "8"
         seg_a | seg_b | seg_c | seg_d | seg_f | seg_g, // char "9"
         seg_a | seg_b | seg_c | seg_e | seg_f | seg_g, // char "A"
         seg_c | seg_d | seg_e | seg_f | seg_g,       // char "b"
         seg_a | seg_d | seg_e | seg_f,             // char "C"
         seg_b | seg_c | seg_d | seg_e | seg_g,       // char "d"
         seg_a | seg_d | seg_e | seg_f | seg_g,       // char "E"
         seg_a | seg_e | seg_f | seg_g};            // char "F"
/*----------------------------------------------------------------------------*/
/* Inital the LCD Drive                                                       */
/*----------------------------------------------------------------------------*/
void Ini_Display(void)
{
  I2C_TARGET  = HY2613_Slave_addr;  //Slave_addr equ  07Ch
  I2C_Sendbuf[0]  = ICSET|SWRst|OscModeInt;  //ICSET equ  0EAh
  I2C_Sendbuf[1]  = DISCTL|PoMode3|FrInv|PoHigh;  //DISCTL equ  0BFh
  I2C_Sendbuf[2]  = ADSET;  //ADSET equ  000h
  I2C_Sendbuf[3]  = ADSET;  //ADSET equ  000h
  I2C_RW = I2C_WRITE;             //

  I2C_DataTxLen=4;
  I2C_DataTxIndex=0;
  I2C_EndFlag=0;
  I2C_Ctrl(1,0,0,0);  /* I2C as master sends START signal */
    __asm__("NOP");
  while (I2C_EndFlag == 0);  /* Wait I2C Tx Finish */
  I2C_EndFlag = 0;

  /*--------------------------------------------------------------------------*/
  /* Open the LCD Drive                                                       */
  /*--------------------------------------------------------------------------*/
  I2C_TARGET  = HY2613_Slave_addr;  //Slave_addr 0x07C
  I2C_Sendbuf[0]  = DISCTL|PoMode3|FrInv|PoHigh;  //
  I2C_Sendbuf[1]  = BLKCTL;  //0xF0
  I2C_Sendbuf[2]  = PIXCTL;  //0xFC
  I2C_Sendbuf[3]  = MODE_SET|Dis_ON;  //0xC8
  I2C_RW = I2C_WRITE;             //

  I2C_DataTxLen=4;
  I2C_DataTxIndex=0;
  I2C_EndFlag=0;
  I2C_Ctrl(1,0,0,0);  /* I2C as master sends START signal */
  __asm__("NOP");
  while (I2C_EndFlag == 0);  /* Wait I2C Tx Finish */
  I2C_EndFlag = 0;
}

/*----------------------------------------------------------------------------*/
/* RAM Data Send to LCD                                                       */
/*----------------------------------------------------------------------------*/
void RAM2LCD(unsigned char *Buffer_Adr, unsigned int length)
{
  I2C_TARGET  = HY2613_Slave_addr;  //Slave_addr equ  07Ch
  I2C_Sendbuf[0]  = DISCTL|PoMode3|FrInv|PoHigh;  //
  I2C_Sendbuf[1]  = BLKCTL;  //0xf0
  I2C_Sendbuf[2]  = PIXCTL;  //0xfc
  I2C_Sendbuf[3]  = MODE_SET|Dis_ON;  //0xc8
  I2C_Sendbuf[4]  = ADSET;  //0x00  //LCD RAM
  I2C_RW = I2C_WRITE;             //
  I2C_DataTxLen=5;

  for(;length>0;length--)
  {
    I2C_Sendbuf[I2C_DataTxLen++]  = (*Buffer_Adr++);
  }
  I2C_DataTxIndex=0;
  I2C_EndFlag=0;
  I2C_Ctrl(1,0,0,0);  /* I2C as master sends START signal */
  __asm__("NOP");
  while (I2C_EndFlag == 0);  /* Wait I2C Tx Finish */
  I2C_EndFlag = 0;
}

/*-------------------------------------------------------------------------------------------------|
|  Function: ClearLCDframe                                                                              |
|                                                                                            					      |
|  Parameters:                                                                                  			   |
|                                                                                              				    |
|  Returns:                                                                              	          |
|         None                                                                                     |
|                                                                                                  |
|  Description:                                                                                						    |
|         																				                                          |
|-------------------------------------------------------------------------------------------------*/
void ClearLCDframe(void)
{
  unsigned char i=0;
  for(i=0;i<9;i++)
  {
    DisplayBuffer[i]=0x00;
  }
  RAM2LCD(DisplayBuffer,9);
}

/*-------------------------------------------------------------------------------------------------|
|  Function: DisplayHYcon                                                                             |
|                                                                                            					      |
|  Parameters:                                                                                  			   |
|                                                                                              				    |
|  Returns:                                                                              	          |
|         None                                                                                     |
|                                                                                                  |
|  Description:                                                                                						    |
|         Display HYcon Char                                          |
|-------------------------------------------------------------------------------------------------*/
void DisplayHYcon(void)
{
  #define offset 0
  DisplayBuffer[offset+0]=0x00;
  DisplayBuffer[offset+1]=Char_H;
  DisplayBuffer[offset+2]=Char_Y;
  DisplayBuffer[offset+3]=Char_c;
  DisplayBuffer[offset+4]=Char_o;
  DisplayBuffer[offset+5]=Char_n;
  RAM2LCD(DisplayBuffer,9);
}

/*-------------------------------------------------------------------------------------------------|
|  Function:                                                                              |
|                                                                                            					      |
|  Parameters:                                                                                  			   |
|                                                                                              				    |
|  Returns:                                                                              	          |
|         None                                                                                     |
|                                                                                                  |
|  Description:                                                                                						    |
|         LCD RAM Data                                           |
|-------------------------------------------------------------------------------------------------*/
void LCD_DATA_DISPLAY(unsigned long LcdBuffer)
{
  unsigned int k=6;
  do
  {
    k--;
    DisplayBuffer[k]=seg[LcdBuffer%10];
    LcdBuffer=LcdBuffer/10;
  }while(k != 0);
  DisplayBuffer[6]=S_Bat1|S_Bat2|S_Bat3|S_Bat4;
  DisplayBuffer[7]=0x00;
  DisplayBuffer[8]=S18|S19|S20|S21;
  RAM2LCD(DisplayBuffer,9);
}

/*-------------------------------------------------------------------------------------------------|
|  Function:   LCD_TEST_DISPLAY                                                 |
|                                                                                            					      |
|  Parameters:                                                                                  			   |
|                                                                                              				    |
|  Returns:                                                                              	          |
|         None                                                                                     |
|                                                                                                  |
|  Description:                                                                                						    |
|         Show all symbol                                           |
|-------------------------------------------------------------------------------------------------*/
void LCD_TEST_DISPLAY(void)
{
	unsigned char i;
	unsigned int num;

	//show minus.zero.tare.m
	for(i=0x02;i<0x10;i=i<<1)
	{
		DisplayBuffer[6]=i;		//	i=S_Zero >> S_Tare >> S_Minus
		RAM2LCD(DisplayBuffer,9);
		for(num=10000;num>0;num--)	__asm__("NOP");
	}
	DisplayBuffer[6]=0;

	//show battery
	for(i=0x10;i>=0x10;i=i<<1)
	{
		DisplayBuffer[6] |=(S_Bat1|i);		// i=S_Bat4 >> S_Bat3 >> S_Bat2
		RAM2LCD(DisplayBuffer,9);
		for(num=10000;num>0;num--)	__asm__("NOP");
	}

	//show mA>
	DisplayBuffer[6]=S_m1;	//m
	DisplayBuffer[7]=S_A;		//A
	DisplayBuffer[8]=S18;		// >
	RAM2LCD(DisplayBuffer,9);
	for(num=10000;num>0;num--)	__asm__("NOP");

	DisplayBuffer[6]=0x00;

	//show K ohm >
	DisplayBuffer[7]=S9|S_Ohm;		// K.ohm
	DisplayBuffer[8]=S19;		// >
	RAM2LCD(DisplayBuffer,9);
	for(num=10000;num>0;num--)	__asm__("NOP");

	//show M V >
	DisplayBuffer[7]=S_M2 | S_V;		// M.V
	DisplayBuffer[8]=S20;		// >
	RAM2LCD(DisplayBuffer,9);
	for(num=10000;num>0;num--)	__asm__("NOP");

	//show E g >
	DisplayBuffer[5]=S_g;
	DisplayBuffer[7]=S11 | S12 | S13;		// E
	DisplayBuffer[8]=S21;		// >
	RAM2LCD(DisplayBuffer,9);
	for(num=10000;num>0;num--)	__asm__("NOP");

	DisplayBuffer[5]=0x00;
	DisplayBuffer[6]=0x00;
	DisplayBuffer[7]=0x00;
	DisplayBuffer[8]=0x00;

	//show num
	for(i=0;i<=5;i++)
	{
		DisplayBuffer[i]=seg[8]|S_g;
		if(i==5) DisplayBuffer[i]=seg[8];
		RAM2LCD(DisplayBuffer,9);
		for(num=10000;num>0;num--)	__asm__("NOP");
	}
}
