#define  USE_HY17M24_2M
/******************************************************************************
 * ADC_I2C.c                                                        *
 * -------------------------------------------------------------------------- *
 * Copyright 2019 HYCON Technology                                            *
 * http://www.hycontek.com/                                                   *
 *                                                                            *
 * Program Description:                                                       *
 *                                                                            *
 * For External Input                                                         *
 * IC Body: HY17M24                                                           *
 * Program Description:
 * S+Addr+0x80+rS+(Addr+1)+CH1Data_L+CH1Data_M+CH1Data_H+CH2Data_L+CH2Data_M+CH2Data_H+CH3Data_L+CH3Data_M+CH3Data_H+CH4Data_L+CH4Data_M+CH4Data_H+P
 * S: Star; Addr: Slave address; rS: repeat start; P: stop.
 * CH1,CH2,CH3,CH4: Force sensor ADC raw data;
 * L: adc low byte; M: adc middle byte; H: adc high byte;
 * I2C : Port PT2.1=SCL, PT2.0=SDA
 * CH1= ADC data, CH2~CH4=Example serial number
 ******************************************************************************/

/*----------------------------------------------------------------------------*/
/* Includes                                                                   */
/*----------------------------------------------------------------------------*/
#include <SFRType.h>
#include <INT.h>
#include <CLK.h>
#include <RST.h>
#include <I2C.h>
#include <PWR.h>
#include <ADC.h>
/*----------------------------------------------------------------------------*/
/* DEFINITIONS                                                                */
/*----------------------------------------------------------------------------*/
volatile typedef union _Flag
{
 unsigned int  _byte;
  struct
  {
    unsigned b_ADCdone:1;
    unsigned b_ADC_Transfer:1;
    unsigned b_I2C_TxDone:1;
    unsigned b_I2C_RxDone:1;
    unsigned Reserved:12;
  };
} Flag;

#define I2CBufferSize  32		// HY17M24 max BufferSize 127
#define I2C_WRITE  0x00       // I2C WRITE command
#define I2C_READ   0x01       // I2C READ command
#define I2C_Slave_Command 0x80
#define ADC_ChopperMode
/*----------------------------------------------------------------------------*/
/* Function PROTOTYPES                                                        */
/*----------------------------------------------------------------------------*/
void SysInit(void);
void SendI2C(signed long  data);
void ADCInit(void);
void I2CInit(void);
void ADCAccuracyModeOFF(void);
void Delay(unsigned int num);
/*----------------------------------------------------------------------------*/
/* Global CONSTANTS                                                           */
/*----------------------------------------------------------------------------*/
//signed long
//range 8388607~-8388608 (dec)
//range 0x007F FFFF ~ 0xFF80 0000 (hex)
signed long  ADC_ISRTemp;
signed long  temp;
unsigned char I2C_RW;
unsigned char I2C_TARGET;      // Target I2C slave address
unsigned char I2C_Sendbuf[I2CBufferSize];
unsigned char I2C_Recbuf[I2CBufferSize];
unsigned char I2C_EndFlag;
Flag   Flagbits;
unsigned int I2C_DataTxLen,I2C_DataTxIndex,I2C_DataRxLen,I2C_DataRxIndex;
unsigned int I2C_GeneralFlag;
char CH1_LowByte, CH2_LowByte, CH3_LowByte, CH4_LowByte;
char CH1_MiddleByte, CH2_MiddleByte, CH3_MiddleByte, CH4_MiddleByte;
char CH1_HighByte, CH2_HighByte, CH3_HighByte, CH4_HighByte;
unsigned char ADC_CH4_Finish;
unsigned char I2C_Start;//I2C slave}lʧ@, ]w1
unsigned int RST_count;//P_ɭI2C SlavenU0xFFI2C SDAQLowʧ@
/*----------------------------------------------------------------------------*/
/* Main Function                                                              */
/*----------------------------------------------------------------------------*/
void main(void)
{
  //Initial Data
  I2C_Start=0;
  RST_count=0;
  CH1_LowByte=0, CH2_LowByte=0, CH3_LowByte=0, CH4_LowByte=0;
  CH1_MiddleByte=0, CH2_MiddleByte=0, CH3_MiddleByte=0, CH4_MiddleByte=0;
  CH1_HighByte=0, CH2_HighByte=0, CH3_HighByte=0, CH4_HighByte=0;
  ADC_CH4_Finish=0;              //Disable I2C Slave data Buffer Update
  I2C_DataRxIndex=0;
  I2C_DataTxIndex=0;
  I2C_EndFlag=0;
  I2C_DataTxLen=I2CBufferSize;

  Flagbits.b_ADCdone = 0;
  Flagbits.b_ADC_Transfer = 0;
  Flagbits.b_I2C_TxDone = 0;
  Flagbits.b_I2C_RxDone = 0;

  SysInit();
  ADCInit();
  I2CInit();
  I2CIE_Disable();
  I2CERIE_Disable();
  GIE_Enable();


  //IF NO ADC Chopper
  while(1)
  {
    while(Flagbits.b_ADCdone==0);  //if ADfinish=0, stop at here, until enter ADC INT
    Flagbits.b_ADCdone=0;
    I2CIE_Disable();
    I2CERIE_Disable();
    ADC_Disable();
    ADC_CMFRDisable();
    //ADC=23bit, +/-22bit, ADC Range : 4194303~-4194304
    CH1_LowByte=(ADC_ISRTemp >> 0) & 0xFF;
    CH1_MiddleByte=(ADC_ISRTemp >> 8) & 0xFF;
    CH1_HighByte=(ADC_ISRTemp >> 16) & 0xFF;
    I2C_Sendbuf[13]=CH1_LowByte;
    I2C_Sendbuf[14]=CH1_MiddleByte;
    I2C_Sendbuf[15]=CH1_HighByte;
    I2C_Sendbuf[16]=0x01;  //CH2 Example serial number
    I2C_Sendbuf[17]=0x02;  //CH2 Example serial number
    I2C_Sendbuf[18]=0x03;  //CH2 Example serial number
    I2C_Sendbuf[19]=0x07;  //CH3 Example serial number
    I2C_Sendbuf[20]=0x08;  //CH3 Example serial number
    I2C_Sendbuf[21]=0x09;  //CH3 Example serial number
    I2C_Sendbuf[22]=0x0B;  //CH4 Example serial number
    I2C_Sendbuf[23]=0x0C;  //CH4 Example serial number
    I2C_Sendbuf[24]=0x0D;  //CH4 Example serial number
    ADC_CH4_Finish=1;      //Enable I2C Slave data Buffer Update
    ADC_Enable();
    ADC_CMFREnable();
    ADC_INT_Enable();
    if(I2C_Start==1)
    {
      RST_count++;
      if(RST_count >=5)
      {
        I2C_SendData(0xFF);//IF SDA lock on LOW, I2C Write 0xFF to unlock SDA LOW issue
      }
    }
  }

}

/*----------------------------------------------------------------------------*/
/* Interrupt Service Routines                                                 */
/*----------------------------------------------------------------------------*/
void ISR(void) __interrupt
{
	//ADC Event
  if(ADC_INT_IsFlag())
  {
    ADC_INT_ClearFlag();
    ADC_ISRTemp=ADCR; //ADC_GetData();
    Flagbits.b_ADCdone= 1;
    ADC_INT_Disable();
    I2CIE_Enable();
    I2CERIE_Enable();
  }

 //I2C Event
 if(I2CIF_IsFlag()) //Get I2C Interrupt Flag
 {
 	  I2C_Start=1;
    RST_count=0;
    switch(I2C_STAState())
    {
      case 0x44: //SACTFlag+ACKFlag
      { //Own slave A + W has been received. ACK has been transmitted.
	      I2C_DataRxIndex= 0;
	      Flagbits.b_I2C_RxDone= 1;
	      I2C_Ctrl(0,0,0,1);  // Set ACK bit
	      break;
      }
			case 0x4C: //SACTFlag+DFFlag+ACKFlag
			{ //Data byte has been received. ACK has been transmitted.

        I2C_ReceiveDATA(temp);  //IF I2C command=0x80
        I2C_Recbuf[I2C_DataRxIndex] = temp;
        if(I2C_Recbuf[I2C_DataRxIndex]==I2C_Slave_Command)
        {
          if(ADC_CH4_Finish==1)
          {
            I2C_Sendbuf[1]=I2C_Sendbuf[13]|0x1;   //Ch1 bit0=1b, new data
            I2C_Sendbuf[2]=I2C_Sendbuf[14];
            I2C_Sendbuf[3]=I2C_Sendbuf[15];
            I2C_Sendbuf[4]=I2C_Sendbuf[16]|0x1;   //Ch2 bit0=1b, new data
            I2C_Sendbuf[5]=I2C_Sendbuf[17];
            I2C_Sendbuf[6]=I2C_Sendbuf[18];
            I2C_Sendbuf[7]=I2C_Sendbuf[19]|0x1;   //Ch3 bit0=1b, new data
            I2C_Sendbuf[8]=I2C_Sendbuf[20];
            I2C_Sendbuf[9]=I2C_Sendbuf[21];
            I2C_Sendbuf[10]=I2C_Sendbuf[22]|0x1;  //Ch4 bit0=1b, new data
            I2C_Sendbuf[11]=I2C_Sendbuf[23];
            I2C_Sendbuf[12]=I2C_Sendbuf[24];
            ADC_CH4_Finish=0;
           }
           else
           {
            I2C_Sendbuf[1]=I2C_Sendbuf[1]|0x0;    //Ch1 bit0=0b, old data
            I2C_Sendbuf[2]=I2C_Sendbuf[2];
            I2C_Sendbuf[3]=I2C_Sendbuf[3];
            I2C_Sendbuf[4]=I2C_Sendbuf[4]|0x0;    //Ch2 bit0=0b, old data
            I2C_Sendbuf[5]=I2C_Sendbuf[5];
            I2C_Sendbuf[6]=I2C_Sendbuf[6];
            I2C_Sendbuf[7]=I2C_Sendbuf[7]|0x0;    //Ch3 bit0=0b, old data
            I2C_Sendbuf[8]=I2C_Sendbuf[8];
            I2C_Sendbuf[9]=I2C_Sendbuf[9];
            I2C_Sendbuf[10]=I2C_Sendbuf[10]|0x0;  //Ch4 bit0=0b, old data
            I2C_Sendbuf[11]=I2C_Sendbuf[11];
            I2C_Sendbuf[12]=I2C_Sendbuf[12];
           }
        }
        I2C_DataRxIndex++;
        I2C_Ctrl(0,0,0,1);  // Set ACK bit
        break;
			}

			case 0x48: //SACTFlag+DFFlag
			{ //Data byte has been received. NACK has been transmitted.
        I2C_ReceiveDATA(temp);
        I2C_Recbuf[I2C_DataRxIndex++] = temp;
	      //I2C_Ctrl(0,0,0,0);  // Clear all I2C flag
	      ACT0&=~(1<<0);  //ACT bit0=0
				break;
			}

			case 0x4A: // I2C General Call
			{ //One data byte has been received. NACK has been transmitted
	      I2C_GeneralFlag= 1;
	      I2C_DataRxIndex= 0;
	      Flagbits.b_I2C_RxDone= 1;
        I2C_ReceiveDATA(temp);
        I2C_Recbuf[I2C_DataRxIndex++] = temp;
	      I2C_Ctrl(0,0,0,1);  // Set ACK bit
	      break;
			}
			case 0x4E: // I2C General Call
			{ //One data byte has been received. ACK has been transmitted
	       I2C_GeneralFlag= 1;
         I2C_ReceiveDATA(temp);
         I2C_Recbuf[I2C_DataRxIndex++] = temp;
	       I2C_Ctrl(0,0,0,1);  // Set ACK bit
	       break;
			}

			case 0x54: //SACTFlag+RWFlag+ACKFlag
			{ //Own slave A + R has been received. ACK has been transmitted.
	      Flagbits.b_I2C_TxDone= 1;
	      I2C_DataTxIndex=0;
	      I2C_DataTxIndex++;  //Robert Add, Read data index
	      I2C_SendData(I2C_Sendbuf[I2C_DataTxIndex++]);  // Send Data to Master
	      //I2C_Ctrl(0,0,0,0);  // Clear all I2C flag
	      ACT0&=~(1<<0);  //ACT bit0=0
	      break;
			};
			case 0x55: //SACTFlag+RWFlag
			{ //Own slave A + R has been received. NACK has been transmitted.
	      I2C_DataTxIndex=0;
	      Flagbits.b_I2C_TxDone= 1;
	      I2C_SendData(I2C_Sendbuf[I2C_DataTxIndex++]);  // Send Data to Master
	      //I2C_Ctrl(0,0,0,0);  // Clear all I2C flag
	      ACT0&=~(1<<0);  //ACT bit0=0
	      break;
			};
			case 0x5C:
			{ //Data byte has been transmitted. ACK has been transmitted.
	      I2C_SendData(I2C_Sendbuf[I2C_DataTxIndex++]);  // Send Data to Master
	      //I2C_Ctrl(0,0,0,0);  // Clear all I2C flag
	      ACT0&=~(1<<0);  //ACT bit0=0
	      break;
			};
			case 0x58:
			{ //Data byte has been transmitted. NACK has been received.
	      I2C_DataTxLen=I2C_DataTxIndex;
	      I2C_EndFlag= 1;
	      I2C_SendData(0x80); // set MSB==High, NACK then STOP
	      //I2C_Ctrl(0,0,0,0);  // Clear all I2C flag
	      ACT0&=~(1<<0);  //ACT bit0=0
	      break;
			};
			case 0x30:
			{ //A STOP  has been received.
	      I2C_DataRxLen=I2C_DataRxIndex;
	      I2C_DataTxLen=I2C_DataTxIndex;
	      I2C_EndFlag= 1;
	      //I2C_Ctrl(0,0,0,0);  // Clear all I2C flag
	      ACT0&=~(1<<0);  //ACT bit0=0
	      break;
			};
			default:
			{
	      I2C_DataTxIndex=0;
	      I2C_DataRxIndex=0;
	      I2C_EndFlag=1;
	      //I2C_Ctrl(0,0,0,0);  // Clear all I2C flag
	      ACT0&=~(1<<0);  //ACT bit0=0
	      break;
			};
		}
	  I2C_I2CINT_CLEAR();
		I2C_I2CER_CLEAR();
		I2CIF_ClearFlag();
		I2C_I2CTF_CLEAR();

  }

  /*
	if(I2CERIF_IsFlag())  //Get I2C Error Interrupt Flag
	{
		I2C_EndFlag=1;
		I2C_I2CINT_CLEAR();
		I2C_I2CER_CLEAR();
		I2CERIF_ClearFlag();
		I2C_I2CTF_CLEAR();
	  I2C_Ctrl(0,1,0,0);   // I2C as master sends STOP signal
	}
	*/


}

/*----------------------------------------------------------------------------*/
/* Subroutine Function                                                        */
/*----------------------------------------------------------------------------*/
/*----------------------------------------------------------------------------*/
/* I2C Init Function                                                          */
/*----------------------------------------------------------------------------*/
void I2CInit(void)
{
	I2C_Open(20);
	I2C_SetIOPin(1);      //I2C Port= PT2.0 & PT2.1
	I2C_SlaveSet(0x20);   //I2C Slave address=0x20
	I2CIE_Enable();
	I2CERIE_Enable();
}

/*----------------------------------------------------------------------------*/
/* System Init Function                                                        */
/*----------------------------------------------------------------------------*/
void SysInit(void)
{
	//PT1.0 HW Reset Function Enable
    PT10_HWResetEnable();
	//CPU CLK SELECT
	CLK_CPUCKOpen(HAOM_2MHZ ,OSCS_HAO ,DHS_HSCKDIV1 ,CPUS_DHSCK );  //Please refer to the Datasheet for HAOM center frequency
}
/*----------------------------------------------------------------------------*/
/* ADC Init Function                                                          */
/*----------------------------------------------------------------------------*/
void ADCInit(void)
{
  //==========Setup Power=====================================
  //PWRCN=0b10000111;         //Enable the internal bandgap and VDDA=VDD
  PWR_BGREnable();
  PWR_VDDAOpen(LDOC_2V4);		//VDDA Enable, refer to the Datasheet for LDOC typical voltage
  ENBOR2_Disable();
  Delay(500);    //Delay 10ms
  //==========Setup ADC=======================================
  //ADC_Open(DADC_DHSCKDIV2,INP_AI0,INN_AI1,VRH_VDDA,VRL_VSS,
  //						ADGN_1,VREGN_DIV1,DCSET_P0,OSR_65536,VCMS_REFOint);
  ADC_Open(DADC_DHSCKDIV2,INP_AI0,INN_AI1,VRH_VDDA,VRL_VSS,
  						ADGN_1,VREGN_DIV1,DCSET_P0,OSR_8192,VCMS_REFOint);

#ifdef ADC_ChopperMode	   //Chopper Mode setup
{
      CSFON_Enable();
      ADC_ENINXCH_Enable();
      ADC_DAFM_CHOPPER();
      ADC_ENCH_Enable();
      ADC_Enable();
      ADC_CMFREnable();     //CMFR=1, Comb Filter Reset
      CSFON_Disable();
}
#endif
}

/*----------------------------------------------------------------------------*/
/* Subroutine Function                                                        */
/*----------------------------------------------------------------------------*/
void Delay(unsigned int num)
{
	for(;num>0;num--)
    __asm__("NOP");
}
/*----------------------------------------------------------------------------*/
/* End Of File                                                                */
/*----------------------------------------------------------------------------*/
