#define  USE_HY17M24_2M
/******************************************************************************
 * GPIO_BZ.c                                                        *
 * -------------------------------------------------------------------------- *
 * Copyright 2019 HYCON Technology                                            *
 * http://www.hycontek.com/                                                   *
 *                                                                            *
 * Program Description:                                           *
 *                                                                            *
 *     HY17M24                                                         *
 * -----------------                                                       *
 *                      |                                                      *
 *                      |                                                      *
 *         PT1.5   |-> BZ                                              *
 *                      |                                                      *
 *                      |                                                      *
 * -----------------                                                         *
 *                                                                            *
 *                                                                            *
 *                                                                            *
 * For External Input                                                         *
 * IC Body: HY17M24                                                           *
 *                                                                                     *
 ******************************************************************************/
/*----------------------------------------------------------------------------*/
/* Includes                                                                   */
/*----------------------------------------------------------------------------*/
#include <SFRType.h>
#include <PWR.h>
#include <GPIO.h>
#include <RST.h>
#include <CLK.h>
#include <WDT.h>

/*----------------------------------------------------------------------------*/
/* DEFINITIONS                                                                */
/*----------------------------------------------------------------------------*/
#define BZ
//#define BZ_1
//#define BZ_2
/*----------------------------------------------------------------------------*/
/* Function PROTOTYPES                                                        */
/*----------------------------------------------------------------------------*/
void GPIOInit(void);
void BZInit(void);
void Delay(unsigned int num);
/*----------------------------------------------------------------------------*/
/* Global CONSTANTS                                                           */
/*----------------------------------------------------------------------------*/
unsigned char cks=0;
/*----------------------------------------------------------------------------*/
/* Main Function                                                              */
/*----------------------------------------------------------------------------*/
void main(void)
{

    //PT1.0 HW Reset Function Enable
    PT10_HWResetEnable();
////	CPU CLK Init		//
	CLK_CPUCKOpen(HAOM_2MHZ ,OSCS_HAO ,DHS_HSCKDIV1 ,CPUS_DHSCK );  //Please refer to the Datasheet for HAOM center frequency

	GPIOInit();
	BZInit();
	GIE_Enable();
	while(1);
}


/*----------------------------------------------------------------------------*/
/* Interrupt Service Routines                                                 */
/*----------------------------------------------------------------------------*/
void ISR(void) __interrupt
{
	if(INTF30_IsFlag())
	{
		Delay(2000);		//debounce
		while(!(GPIO_PT3GET(PT30_H)));	//wait PT30=0

		if(++cks >3) cks = 3;
	}
	if(INTF31_IsFlag())
	{
		Delay(2000);		//debounce
		while(!(GPIO_PT3GET(PT31_H)));	//wait PT31=0
		if(--cks >3) cks = 0;
	}
	switch(cks)
	{
		case 0:
			BZ_BZCKSelect(DBZ_DZCKDIV2);		//Output BZ_CK = BZ_CLK / 2
		break;

		case 1:
			BZ_BZCKSelect(DBZ_DZCKDIV4);		//Output BZ_CK = BZ_CLK / 4
		break;

		case 2:
			BZ_BZCKSelect(DBZ_DZCKDIV8);		//Output BZ_CK = BZ_CLK / 8
		break;

		case 3:
			BZ_BZCKSelect(DBZ_DZCKDIV16);		//Output BZ_CK = BZ_CLK / 16
		break;
	}
	INTF30_ClearFlag();
	INTF31_ClearFlag();

}
/*----------------------------------------------------------------------------*/
/* Subroutine Function                                                        */
/*----------------------------------------------------------------------------*/
/*----------------------------------------------------------------------------*/
/*        GPIO Init function                                                           */
/*----------------------------------------------------------------------------*/
void GPIOInit(void)
{
	GPIO_PT3InputEnable(IN30_H | IN31_H);		//PT30.PT31 Digital mode
	GPIO_PT3InputEnable(IN31);
	GPIO_PT3InputMode(TC30_L | TC30_L);			//PT30.PT31 Input mode
	GPIO_PT3SETPU(PU30_H | PU31_H);				//PT30.PT31 Pull-up	resistors Enable
	INTG30_Edgefall();		//PT30 INT triggering conditions 1->0
	INTE30_Enable();		//PT30 INT Enable
	INTG31_Edgefall();		//PT31 INT triggering conditions 1->0
	INTE31_Enable();		//PT31 INT Enable
}
/*----------------------------------------------------------------------------*/
/*        BZ Init function                                                           */
/*----------------------------------------------------------------------------*/
void BZInit(void)
{
	CLK_DMSCKSelect(DMS_DHSCKDIV2);	//DMS_CK = DHS_CK /2
	BZ_CLKSelect(BZS_LSCK);						//BZ_CLK = LS_CK = DMS_CK / 8
	BZ_BZCKSelect(DBZ_DZCKDIV2);		//Output BZ_CK = BZ_CLK / 2

	//	BZ -> PT15	//
#ifdef BZ
	GPIO_PT1InputEnable(IN15_H);		//PT15 Digital mode
	GPIO_PT1OutputMode(TC15_H);		//PT15 Output mode
	GPIO_PM15Sel(PM15_BZ);				//PT15 BZ mode
#endif

	//	BZ_1 -> PT21	//
#ifdef BZ_1
	GPIO_PT2InputEnable(IN21_H);		//PT21 Digital mode
	GPIO_PT2OutputMode(TC21_H);		//PT21 Output mode
	GPIO_PM21Sel(PM21_BZ_1);			//PT21 BZ_1 mode
#endif

	//	BZ_2 -> PT34	//
#ifdef BZ_2
	GPIO_PT3InputEnable(IN34_H);		//PT34 Digital mode
	GPIO_PT3OutputMode(TC34_H);		//PT34 Output mode
	GPIO_PM34Sel(PM34_BZ_2);			//PT34 BZ_2 mode
#endif
	BZ_Enable();

}
/*----------------------------------------------------------------------------*/
/* Software Delay Subroutines                                                 */
/*----------------------------------------------------------------------------*/
void Delay(unsigned int num)
{
	for(;num>0;num--)
    __asm__("NOP");
}

/*----------------------------------------------------------------------------*/
/* End Of File                                                                */
/*----------------------------------------------------------------------------*/
