#define  USE_HY17M24_2M
/******************************************************************************
 * HY17M24_ADC.c                                                        *
 * -------------------------------------------------------------------------- *
 * Copyright 2019 HYCON Technology                                            *
 * http://www.hycontek.com/                                                   *
 *                                                                            *
 * Program Description:                                                       *
 *                                                                            *
 * For External Input                                                         *
 * IC Body: HY17M24                                                           *

 ******************************************************************************/

/*----------------------------------------------------------------------------*/
/* Includes                                                                   */
/*----------------------------------------------------------------------------*/
#include <SFRType.h>
#include <INT.h>
#include <CLK.h>
#include <PWR.h>
#include <ADC.h>
#include <RST.h>
#include <TMR.h>
#include <OPA.h>
/*----------------------------------------------------------------------------*/
/* DEFINITIONS                                                                */
/*----------------------------------------------------------------------------*/
volatile typedef union _Flag
{
 unsigned int  _byte;
  struct
  {
    unsigned b_ADCdone:1;
    unsigned b_TMAdone:1;
    unsigned Reserved:14;
  };
} Flag;

#define ADC_ChopperMode
/*----------------------------------------------------------------------------*/
/* Function PROTOTYPES                                                        */
/*----------------------------------------------------------------------------*/
void SysInit(void);
void Delay_NOP(unsigned int del);
void ADCInit(void);
/*----------------------------------------------------------------------------*/
/* Global CONSTANTS                                                           */
/*----------------------------------------------------------------------------*/
//signed long
//range 8388607~-8388608 (dec)
//range 0x007F FFFF ~ 0xFF80 0000 (hex)
signed long  ADC_ISRTemp;
signed long  ADC_ISRTemp_Buffer[8];
unsigned int counterA;
Flag   Flagbits;
/*----------------------------------------------------------------------------*/
/* Main Function                                                              */
/*----------------------------------------------------------------------------*/
void main(void)
{
  //PT1.0 HW Reset Function Ensable
  PT10_HWResetEnable();

  //CPU CLK SELECT
  CLK_CPUCKOpen(HAOM_2MHZ ,OSCS_HAO ,DHS_HSCKDIV1 ,CPUS_DHSCK );  //Please refer to the Datasheet for HAOM center frequency

  counterA=0;
  Flagbits.b_ADCdone=0;
  ADCInit();
  GIE_Enable();

  while(1)
  {

    if(Flagbits.b_ADCdone==1)
    {
      ADC_ISRTemp_Buffer[counterA]=ADC_ISRTemp;
      Flagbits.b_ADCdone=0;
      counterA++ ;
      if( counterA==8 )
      {
        counterA=0;
      }
    }
  }
}

/*----------------------------------------------------------------------------*/
/* Interrupt Service Routines                                                 */
/*----------------------------------------------------------------------------*/
void ISR(void) __interrupt
{
  NOP();

  //ADC Event
  if(ADC_INT_IsFlag())
  {
    ADC_INT_ClearFlag();
    ADC_ISRTemp=ADCR; //ADC_GetData();
    Flagbits.b_ADCdone=1;
  }

}

/*----------------------------------------------------------------------------*/
/* Subroutine Function                                                        */
/*----------------------------------------------------------------------------*/
void Delay_NOP(unsigned int del)
{
  while(--del)
  NOP();
}


/*----------------------------------------------------------------------------*/
/* ADC Init Function                                                          */
/*----------------------------------------------------------------------------*/
void ADCInit(void)
{
   //==========Setup Power=====================================
  PWR_BGREnable();					//bandgap Vref Enable
  PWR_VDDAOpen(LDOC_2V4);	//VDDA Enable, refer to the Datasheet for LDOC typical voltage

  //==========Setup ADC=======================================
  ADC_Open(DADC_DHSCKDIV2,INP_AI0,INN_AI1,VRH_VDDA,VRL_VSS,
 						ADGN_1,VREGN_DIV1,DCSET_P0,OSR_65536,VCMS_REFOint);
#ifdef ADC_ChopperMode
{
      CSFON_Enable();
      ADC_ENINXCH_Enable();
      ADC_DAFM_CHOPPER();
      ADC_ENCH_Enable();
      ADC_Enable();
      ADC_CMFREnable();     //CMFR=1, Comb Filter Reset
      CSFON_Disable();
 }
 #endif
}

/*----------------------------------------------------------------------------*/
/* End Of File                                                                */
/*----------------------------------------------------------------------------*/
