#define  USE_HY17M24_2M
/******************************************************************************
 * HY17M24_ADC_UART.c                                                        *
 * -------------------------------------------------------------------------- *
 * Copyright 2019 HYCON Technology                                            *
 * http://www.hycontek.com/                                                   *
 *                                                                            *
 * Program Description:                                                       *
 *            HY17M24                                                                *
 * ----------------------                                                *
 *                           |                                                *
 *                 PT1.5|->TX                                        *
 *                 PT1.6|->RX                                       *
 *                           |                                                 *
 *----------------------                                                  *
 * For External Input                                                         *
 * IC Body: HY17M24                                                           *

 ******************************************************************************/
/*----------------------------------------------------------------------------*/
/* Includes                                                                   */
/*----------------------------------------------------------------------------*/
#include <SFRType.h>
#include <INT.h>
#include <CLK.h>
#include <RST.h>
#include <UART.h>
#include <PWR.h>
#include <ADC.h>
/*----------------------------------------------------------------------------*/
/* DEFINITIONS                                                                */
/*----------------------------------------------------------------------------*/
//#define UART_ABD

volatile typedef union _Flag
{
 unsigned int  _byte;
  struct
  {
    unsigned b_ADCdone:1;
    unsigned b_TMAdone:1;
    unsigned b_UART_TxDone:1;
    unsigned b_UART_RxDone:1;
    unsigned Reserved:12;
  };
} Flag;

//                0        1           2          3
//     TX  PT1.5  PT2.0  PT3.6  PT3.4
//     RX  PT1.6  PT2.1  PT3.7  PT3.5

#define  Uart_RX_BufferSize 10
#define  Uart_TX_BufferSize 10
/*----------------------------------------------------------------------------*/
/* Function PROTOTYPES                                                        */
/*----------------------------------------------------------------------------*/
void SysInit(void);
void Delay(unsigned int num);
void CLOCKInit(void);
void UARTInit(void);
void ADCInit(void);
void SendUART(signed long  data);
/*----------------------------------------------------------------------------*/
/* Global CONSTANTS                                                           */
/*----------------------------------------------------------------------------*/
//signed long
//range 8388607~-8388608 (dec)
//range 0x007F FFFF ~ 0xFF80 0000 (hex)
signed long  ADC_ISRTemp;
signed long  ADC_ISRTemp_Buffer[8];
signed long  ADCData1;
Flag   Flagbits;
unsigned char UartTxBuffer[Uart_TX_BufferSize]={0};
unsigned char UartRxBuffer[Uart_RX_BufferSize]={0};
unsigned char UartTxIndex,UartTxLength;
unsigned char UartRxIndex,UartRxLength;
/*----------------------------------------------------------------------------*/
/* Main Function                                                              */
/*----------------------------------------------------------------------------*/
void main(void)
{
  //PT1.0 HW Reset Function Enable
  PT10_HWResetEnable();

  //ADC_UART Demo
  UartTxIndex= 0;
  UartRxIndex= 0;
  Flagbits.b_ADCdone= 0;
  Flagbits.b_UART_TxDone= 0;
  Flagbits.b_UART_RxDone= 0;

  CLOCKInit();
  ADCInit();
  UARTInit();
  Flagbits.b_UART_TxDone=1;
  GIE_Enable();

  while(1)
  {

  	Flagbits.b_ADCdone=0;
    while(Flagbits.b_ADCdone==0);  //until get ADC_ISRTemp
    Flagbits.b_ADCdone=0;

    ADC_INT_Disable();
    SendUART(ADC_ISRTemp);
    ADC_INT_Enable();

  }

}

/*----------------------------------------------------------------------------*/
/* Interrupt Service Routines                                                 */
/*----------------------------------------------------------------------------*/
void ISR(void) __interrupt
{

  NOP();

  //ADC Event
  if(ADC_INT_IsFlag())
  {
    ADC_INT_ClearFlag();
    ADC_ISRTemp=ADCR; //ADC_GetData();
    Flagbits.b_ADCdone=1;
  }

  //UART RX Event
  if(UART_INT_RCIsFlag())
  {
    UartRxBuffer[UartRxIndex]=RC0REG;
    UartRxIndex++;
    if(UartRxIndex>=Uart_RX_BufferSize)
    {
      UartRxIndex=0;
      Flagbits.b_UART_RxDone=1;
    }
    UART_INT_RCClearFlag();
  }

  //UART TX Event
  if(UART_INT_TXIsFlag())
  {
    if(Flagbits.b_UART_TxDone==0)
    {
      TX0R=UartTxBuffer[UartTxIndex++];
      UART_INT_TXClearFlag();
      if(UartTxIndex>=UartTxLength)
      {
        UART_INT_TXEnable();    //TXIE=1b
        UART_INT_RCEnable();  //RCIE=1b
        Flagbits.b_UART_TxDone=1;
        UartTxIndex=0;
      }
    }
      if(Flagbits.b_UART_TxDone==1)
      {
        UART_INT_TXDisable();    //TXIE=0b
        UART_INT_RCEnable();  //RCIE=1b
        UART_INT_TXClearFlag();
      }
    }

}

/*----------------------------------------------------------------------------*/
/* Subroutine Function                                                        */
/*----------------------------------------------------------------------------*/
void Delay_NOP(unsigned int del)
{
  while(--del)
  NOP();
}

/*----------------------------------------------------------------------------*/
/* UART Init Function                                                          */
/*----------------------------------------------------------------------------*/
void UARTInit(void)
{
#ifdef UART_ABD
  UART_Open(0 ,8 ,PARITY_None ,0);
  UART_WUEDisable();                   // Wake-up disable
  UART_ABDEnable();                    //Enable Auto Baudrate
  while((BA0CN & 0x01) == 1 );      //Wait for master send 055H
  UART_INT_RCClearFlag();          //Clear RC interrupt flag
#else
  UART_Open(48 ,8 ,PARITY_EVEN ,0);    //HAO=2MHz,baud=9600
#endif
  TXIE_Enable();
  RCIE_Enable();
}
/*----------------------------------------------------------------------------*/
/* CLOCK Init Function                                                        */
/*----------------------------------------------------------------------------*/
void CLOCKInit(void)
{
	CLK_CPUCKOpen(HAOM_2MHZ ,OSCS_HAO ,DHS_HSCKDIV1 ,CPUS_DHSCK ); //Please refer to the Datasheet for HAOM center frequency

}

/*----------------------------------------------------------------------------*/
/* ADC Init Function                                                          */
/*----------------------------------------------------------------------------*/
void ADCInit(void)
{
   //==========Setup Power=====================================
  ENBOR2_Disable();
  PWR_BGREnable();					//bandgap Vref Enable
  PWR_VDDAOpen(LDOC_2V4);	//VDDA Enable, refer to the Datasheet for LDOC typical voltage
  PWR_LDOMode(LDOM_VDD);
  Delay(500);    //Delay 10ms

  //==========Setup ADC=======================================
 ADC_Open(DADC_DHSCKDIV2,INP_AI0,INN_AI1,VRH_VDDA,VRL_VSS,
 						ADGN_1,VREGN_DIV1,DCSET_P0,OSR_65536,VCMS_REFOint);

  //==========Setup ADC INT======================================
  ADC_INT_ClearFlag();      //Clear ADIF
  ADC_INT_Enable();   //ADC INT Enable
  ADC_Enable();         //ADC Enable
  ADC_CMFREnable();     //CMFR=1, Comb Filter Reset

}
/*----------------------------------------------------------------------------*/
/* Function Name: void SendUART(int data)                                     */
/* Description  : UART send data.                                             */
/* Arguments    : None.                                                       */
/* Return Value : None.                                                       */
/* Remark       :                                                             */
/*----------------------------------------------------------------------------*/
void SendUART(signed long  data)
{

  //display range +8388607~-8388608 (dec)

  ADCData1=data;
  if((ADCData1<0)||(ADCData1>0x80000000))  // plus-minus sign judgment
  {
	  ADCData1=~ADCData1;
	  ADCData1++;
    UartTxBuffer[0]='-';
  }
  else
  {
    UartTxBuffer[0]='+';
  }
  UartTxBuffer[7]=ADCData1%10 | '0';  //unit
  ADCData1=ADCData1/10;
  UartTxBuffer[6]=ADCData1%10 | '0';  //unit
  ADCData1=ADCData1/10;
  UartTxBuffer[5]=ADCData1%10 | '0';  //ten
  ADCData1=ADCData1/10;
  UartTxBuffer[4]=ADCData1%10 | '0';  //hundred
  ADCData1=ADCData1/10;
  UartTxBuffer[3]=ADCData1%10 | '0';  //thousand
  ADCData1=ADCData1/10;
  UartTxBuffer[2]=ADCData1%10 | '0';  //ten thousand
  ADCData1=ADCData1/10;
  UartTxBuffer[1]=ADCData1%10 | '0';  //hundred thousand
  ADCData1=ADCData1/10;
  UartTxBuffer[8]='\r';
  UartTxBuffer[9]='\n';
  Flagbits.b_UART_TxDone=0;
  UartTxLength=10;
  UartTxIndex=0;
  TXIE_Enable();    //Enable UART Tx Interrupt;
  RCIE_Enable();   //Enable UART Rx Interrupt
  while(!Flagbits.b_UART_TxDone);  //If  Flagbits.b_UART_TxDone=DISABLE, stop at here
}

/*----------------------------------------------------------------------------*/
/* Software Delay Subroutines                                                 */
/*----------------------------------------------------------------------------*/
void Delay(unsigned int num)
{
	for(;num>0;num--)
    __asm__("NOP");
}

/*----------------------------------------------------------------------------*/
/* End Of File                                                                */
/*----------------------------------------------------------------------------*/
