#define  USE_HY17M24_2M
/******************************************************************************
 * HY17M24_CMP.c                                                        *
 * -------------------------------------------------------------------------- *
 * Copyright 2019 HYCON Technology                                            *
 * http://www.hycontek.com/                                                   *
 *                                                                            *
 * Program Description:                                                       *
 *                                                                            *
 *        HY17M24                                                     *
 *--------------------                                                     *
 *                       |                                                     *
 *             PT1.6|->Output                                       *
 *                       |                                                     *
 *             PT3.7|->Input                                          *
 *                       |                                                     *
 *--------------------                                                     *
 *                                                                             *
 * For External Input                                                         *
 * IC Body: HY17M24                                                           *

 ******************************************************************************/
/*----------------------------------------------------------------------------*/
/* Includes                                                                   */
/*----------------------------------------------------------------------------*/
#include <SFRType.h>
#include <PWR.h>
#include <GPIO.h>
#include <RST.h>
#include <ADC.h>
#include <CLK.h>
#include <CMP.h>

/*----------------------------------------------------------------------------*/
/* DEFINITIONS                                                                */
/*----------------------------------------------------------------------------*/
//#define hysteresis_mode
#define LVD_mode

/*----------------------------------------------------------------------------*/
/* Function PROTOTYPES                                                        */
/*----------------------------------------------------------------------------*/
void SysInit(void);
void Delay(unsigned int num);
/*----------------------------------------------------------------------------*/
/* Global CONSTANTS                                                           */
/*----------------------------------------------------------------------------*/

/*----------------------------------------------------------------------------*/
/* Main Function                                                              */
/*----------------------------------------------------------------------------*/
void main(void)
{
	SysInit();
#ifdef hysteresis_mode
	CMP_Open(CPPS_CH2,CPNS_RLO,CMPHS_NORMAL,CPOR_NORMAL,ENRCC_PT16);
	GPIO_PT3SETDA(DA37_H);			//PT37 CH2 INPUT
	CMP_RLOSet(CPRH_VDDA,CPRL_OPEN,CPDA_5DIV32,CPDM2_ENABLE);    // Lower than 0.81V &  Higher 0.97V
	PWR_VDDAOpen(LDOC_2V9); // Refer to the Datasheet for LDOC typical voltage
#endif

#ifdef LVD_mode
	CMP_Open(CPPS_1V2,CPNS_RLO,CMPHS_NORMAL,CPOR_NORMAL,ENRCC_PT16);
	CMP_RLOSet(CPRH_VDD,CPRL_OPEN,CPDA_12DIV32,CPDM_DISABLE );    // VDD=3.3V, LVD=2.8
#endif


	GIE_Enable();
	while(1);
}


/*----------------------------------------------------------------------------*/
/* Interrupt Service Routines                                                 */
/*----------------------------------------------------------------------------*/

/*----------------------------------------------------------------------------*/
/* Subroutine Function                                                        */
/*----------------------------------------------------------------------------*/

/*----------------------------------------------------------------------------*/
/* System Init Function                                                          */
/*----------------------------------------------------------------------------*/
void SysInit(void)
{
	//PT1.0 HW Reset Function Disable
    PT10_HWResetEnable();

	//CPU CLK SELECT
	CLK_CPUCKOpen(HAOM_2MHZ ,OSCS_HAO ,DHS_HSCKDIV1 ,CPUS_DHSCK ); //Please refer to the Datasheet for HAOM center frequency

	//PT16 OUTPUT
	GPIO_PT1OutputMode(TC16_H);		//PT16 Output mode
	GPIO_PT1InputEnable(IN16_H);		//PT16 Digital mode

}

/*----------------------------------------------------------------------------*/
/* Software Delay Subroutines                                                 */
/*----------------------------------------------------------------------------*/
void Delay(unsigned int num)
{
	for(;num>0;num--)
    __asm__("NOP");
}

/*----------------------------------------------------------------------------*/
/* End Of File                                                                */
/*----------------------------------------------------------------------------*/
