#define  USE_HY17M24_2M
/******************************************************************************
 * HY17M24_OPA.c                                                        *
 * -------------------------------------------------------------------------- *
 * Copyright 2019 HYCON Technology                                            *
 * http://www.hycontek.com/                                                   *
 *                                                                            *
 * Program Description:                                                       *
 *                                                                            *
 *    HY17M24                                                                        *
 *-----------------                                                                            *
 *                    |                                                        *
 *                    |                                                        *
 *            AI0  |-> INP                                                             *
 *                    |                                                       *
 *         PT3.4 |->Output                                                *
 *                    |                                                        *
 *-----------------                                                                    *
 *                                                                            *
 * For External Input                                                         *
 * IC Body: HY17M24                                                           *

 ******************************************************************************/
/*----------------------------------------------------------------------------*/
/* Includes                                                                   */
/*----------------------------------------------------------------------------*/
#include <SFRType.h>
#include <PWR.h>
#include <ADC.h>
#include <GPIO.h>
#include <RST.h>
#include <CLK.h>
#include <INT.h>
#include <OPA.h>
/*----------------------------------------------------------------------------*/
/* DEFINITIONS                                                                */
/*----------------------------------------------------------------------------*/

/*----------------------------------------------------------------------------*/
/* Function PROTOTYPES                                                        */
/*----------------------------------------------------------------------------*/
void SysInit(void);
void Delay(unsigned int num);
/*----------------------------------------------------------------------------*/
/* Global CONSTANTS                                                           */
/*----------------------------------------------------------------------------*/
unsigned char opa_flag;
/*----------------------------------------------------------------------------*/
/* Main Function                                                              */
/*----------------------------------------------------------------------------*/
void main(void)
{
	SysInit();

	//	OPA SETTING	//
	OP1_INPSet(OP1INP_AI0_ENABLE);
	OP1_INN0Set(OP1INN0_REFOI_ENABLE);
	OPA_Out2DigOpen(OPINS_NORMAL,OPDR_NORMAL,OPOEG_LEV);    //Select digital mode

	GIE_Enable();
	while(1);
}


/*----------------------------------------------------------------------------*/
/* Interrupt Service Routines                                                 */
/*----------------------------------------------------------------------------*/
void ISR(void) __interrupt
{
    unsigned char opc_status;
	if(OPCIF_IsFlag())
	{
			OP1_OPCRead(opc_status);

			if(opc_status)
			GPIO_PT3OutputHigh(PT34_H);// INP>INN -> PT34 Output high
			else
			GPIO_PT3OutputLow(PT34_MSK);// INP<INN -> PT34 Output low

			OPCIF_ClearFlag();		//OPCIF clear
	}

}
/*----------------------------------------------------------------------------*/
/* Subroutine Function                                                        */
/*----------------------------------------------------------------------------*/
/*----------------------------------------------------------------------------*/
/* System Init Function                                                          */
/*----------------------------------------------------------------------------*/
void SysInit(void)
{
    //PT1.0 HW Reset Function Ensable
    PT10_HWResetEnable();
    //CPU CLK SELECT
    CLK_CPUCKOpen(HAOM_2MHZ ,OSCS_HAO ,DHS_HSCKDIV1 ,CPUS_DHSCK );  //Please refer to the Datasheet for HAOM center frequency

    //Setting GPIO
    GPIO_PT3InputEnable(IN34_H);		//PT34 Digital mode
    GPIO_PT3OutputMode(TC34_H);		//PT34 Output mode
    GPIO_PT3OutputHigh(PT34_H);			//PT34 Output high

    //REFOI ENABLE
    PWR_VDDAOpen(LDOC_2V9);				//VDDA Enable, refer to the Datasheet for LDOC typical voltage
    REFOI_REFOint_Open(REFOS_2V0);	//REFOint Enable, REFOI=2.0V, refer to the Datasheet for REFOS typical voltage
    Delay(500);
}

/*----------------------------------------------------------------------------*/
/* Software Delay Subroutines                                                 */
/*----------------------------------------------------------------------------*/
void Delay(unsigned int num)
{
	for(;num>0;num--)
    __asm__("NOP");
}

/*----------------------------------------------------------------------------*/
/* End Of File                                                                */
/*----------------------------------------------------------------------------*/
