#define  USE_HY17M24_2M
/******************************************************************************
 * HY17M24_UART.c                                                        *
 * -------------------------------------------------------------------------- *
 * Copyright 2019 HYCON Technology                                            *
 * http://www.hycontek.com/                                                   *
 *                                                                            *
 * Program Description:                                                       *
 *                                                                            *
 *          HY17M24                                                  *
 * ----------------------                                                *
 *                           |                                                *
 *                 PT1.5|->TX                                        *
 *                 PT1.6|->RX                                       *
 *                           |                                                 *
 *----------------------                                                  *
 *                                                                            *
 * For External Input                                                         *
 * IC Body: HY17M24                                                           *

 ******************************************************************************/
/*----------------------------------------------------------------------------*/
/* Includes                                                                   */
/*----------------------------------------------------------------------------*/
#include <SFRType.h>
#include <INT.h>
#include <CLK.h>
#include <RST.h>
#include <GPIO.h>
#include <UART.h>

/*----------------------------------------------------------------------------*/
/* DEFINITIONS                                                                */
/*----------------------------------------------------------------------------*/
#define UART_ABD

volatile typedef union _Flag
{
 unsigned int  _byte;
  struct
  {
    unsigned b_ADCdone:1;
    unsigned b_TMAdone:1;
    unsigned b_UART_TxDone:1;
    unsigned b_UART_RxDone:1;
    unsigned Reserved:12;
  };
} Flag;

//      0      1      2      3
//     TX  PT1.5  PT2.0  PT3.6  PT3.4
//     RX  PT1.6  PT2.1  PT3.7  PT3.5

#define  Uart_RX_BufferSize 6
#define  Uart_TX_BufferSize 10
/*----------------------------------------------------------------------------*/
/* Function PROTOTYPES                                                        */
/*----------------------------------------------------------------------------*/
void SysInit(void);
void Delay_NOP(unsigned int del);
void CLOCKInit(void);
void UARTInit(void);
/*----------------------------------------------------------------------------*/
/* Global CONSTANTS                                                           */
/*----------------------------------------------------------------------------*/
Flag   Flagbits;
unsigned char UartTxBuffer[Uart_TX_BufferSize]={0};
unsigned char UartRxBuffer[Uart_RX_BufferSize]={0};
unsigned char UartTxIndex,UartTxLength;
unsigned char UartRxIndex,UartRxLength;
unsigned char STOP_TO_SEND_UART;
//STOP_TO_SEND_UART command
unsigned char UartRxBuffer_Command[Uart_RX_BufferSize]=
{
0x61,0x62,0x63,0x64,0x65,0x66 //ASCII  KEYWORD = abcdef
};
/*----------------------------------------------------------------------------*/
/* Main Function                                                              */
/*----------------------------------------------------------------------------*/
void main(void)
{
  //PT1.0 HW Reset Function Enable
  PT10_HWResetEnable();

  //UART Demo
  STOP_TO_SEND_UART=0;
  Flagbits.b_UART_TxDone=0;
  Flagbits.b_UART_RxDone=0;
  CLOCKInit();
  UARTInit();
  Flagbits.b_UART_TxDone=1;
  GIE_Enable();

  UartTxIndex=0;
  UartRxIndex=0;;

  while(1)
  {


    //UART RX
    if(Flagbits.b_UART_RxDone==1)
    {

      if(
        (UartRxBuffer[5]==UartRxBuffer_Command[5] && UartRxBuffer[4]==UartRxBuffer_Command[4]) &&
        (UartRxBuffer[3]==UartRxBuffer_Command[3] && UartRxBuffer[2]==UartRxBuffer_Command[2]) &&
        (UartRxBuffer[1]==UartRxBuffer_Command[1] && UartRxBuffer[0]==UartRxBuffer_Command[0])
        )
      {
        //if UART receive == 0x61(a)0x62(b)0x63(c)0x64(d)0x65(e)0x66(f)
        //send out 0x61(a)0x62(b)0x63(c)0x64(d)0x65(e)0x66(f) and stop to send out
        STOP_TO_SEND_UART=1;
        for(UartTxLength=0;UartTxLength<=Uart_TX_BufferSize;UartTxLength++)
        {
          UartTxBuffer[UartTxLength]=UartRxBuffer[UartTxLength];
          if(UartTxLength==Uart_RX_BufferSize)
          {
            UartRxIndex=0;
            Flagbits.b_UART_TxDone=0;
            UART_INT_TXEnable();    //TXIE=1b
            UART_INT_RCDisable();  //RCIE=0b
            while(!Flagbits.b_UART_TxDone);
          }
        }
      }
      else
      {
      //if UART receive != 0x61(a)0x62(b)0x63(c)0x64(d)0x65(e)0x66(f)
      //User defined at here
      STOP_TO_SEND_UART=0;
      }

      UartRxIndex=0;
      Flagbits.b_UART_RxDone=0;

    }


    if(Flagbits.b_UART_TxDone==1 && STOP_TO_SEND_UART==0)
    {
      UartTxBuffer[7]='\r';
      UartTxBuffer[6]='\n';
      UartTxBuffer[5]=0x46;  //F
      UartTxBuffer[4]=0x45;  //E
      UartTxBuffer[3]=0x44;  //D
      UartTxBuffer[2]=0x43;  //C
      UartTxBuffer[1]=0x42;  //B
      UartTxBuffer[0]=0x41;  //A
      Flagbits.b_UART_TxDone=0;
      UartTxLength=8;
      UartTxIndex=0;
      UART_INT_TXEnable();    //TXIE=1b
      UART_INT_RCEnable();  //RCIE=1b
      while(!Flagbits.b_UART_TxDone);  //If  Flagbits.b_UART_TxDone=DISABLE, stop at here
      Delay_NOP(3000);
    }
  }
}

/*----------------------------------------------------------------------------*/
/* Interrupt Service Routines                                                 */
/*----------------------------------------------------------------------------*/
void ISR(void) __interrupt
{

  NOP();

  //UART RX Event
  if(UART_INT_RCIsFlag())
  {
    UartRxBuffer[UartRxIndex]=RC0REG;
    UartRxIndex++;
    if(UartRxIndex>=Uart_RX_BufferSize)
    {
      UartRxIndex=0;
      Flagbits.b_UART_RxDone=1;
    }
    UART_INT_RCClearFlag();
  }

  //UART TX Event
  if(UART_INT_TXIsFlag())
  {
    if(Flagbits.b_UART_TxDone==0)
    {
      TX0R=UartTxBuffer[UartTxIndex++];
      UART_INT_TXClearFlag();
      if(UartTxIndex>=UartTxLength)
      {
        UART_INT_TXEnable();    //TXIE=1b
        UART_INT_RCEnable();  //RCIE=1b
        Flagbits.b_UART_TxDone=1;
        UartTxIndex=0;
      }
    }
      if(Flagbits.b_UART_TxDone==1)
      {
        UART_INT_TXDisable();    //TXIE=0b
        UART_INT_RCEnable();  //RCIE=1b
        UART_INT_TXClearFlag();
      }
    }

}

/*----------------------------------------------------------------------------*/
/* Subroutine Function                                                        */
/*----------------------------------------------------------------------------*/
void Delay_NOP(unsigned int del)
{
  while(--del)
  NOP();
}

/*----------------------------------------------------------------------------*/
/* UART Init Function                                                          */
/*----------------------------------------------------------------------------*/
void UARTInit(void)
{
#ifdef UART_ABD
  UART_Open(0 ,8 ,PARITY_None ,0);
  UART_WUEDisable();                   // Wake-up disable
  UART_ABDEnable();                    //Enable Auto Baudrate
  while((BA0CN & 0x01) == 1 );      //Wait for master send 055H
  UART_INT_RCClearFlag();          //Clear RC interrupt flag
#else
  UART_Open(48 ,8 ,PARITY_EVEN ,0);    //HAO=2MHz,baud=9600
#endif
  TXIE_Enable();
  RCIE_Enable();

}
/*----------------------------------------------------------------------------*/
/* CLOCK Init Function                                                        */
/*----------------------------------------------------------------------------*/
void CLOCKInit(void)
{
  //Please refer to the Datasheet for HAOM center frequency
  CLK_CPUCKOpen(HAOM_2MHZ ,OSCS_HAO ,DHS_HSCKDIV1 ,CPUS_DHSCK );

}
/*----------------------------------------------------------------------------*/
/* End Of File                                                                */
/*----------------------------------------------------------------------------*/
