#define  USE_HY17M24_2M
/******************************************************************************
 * I2C_HY2613.c                                                        *
 * -------------------------------------------------------------------------- *
 * Copyright 2019 HYCON Technology                                            *
 * http://www.hycontek.com/                                                   *
 *                                                                            *
 * Program Description:                                                       *
 *                                                                            *
 * For External Input                                                         *
 * IC Body: HY17M24                                                           *

 ******************************************************************************/
/*----------------------------------------------------------------------------*/
/* Includes                                                                   */
/*----------------------------------------------------------------------------*/
#include <SFRType.h>
#include <INT.h>
#include <CLK.h>
#include <RST.h>
#include <I2C.h>
#include <GPIO.h>
#include "HY2613.h"
#include "seg7.h"

/*----------------------------------------------------------------------------*/
/* DEFINITIONS                                                                */
/*----------------------------------------------------------------------------*/
#define I2CBufferSize  11		// HY17M24 max BufferSize 127
#define I2C_WRITE  0x00       // I2C WRITE command
#define I2C_READ   0x01       // I2C READ command
#define I2C_Delay  1000000    //HAO=2MHz, wait 5s
/*----------------------------------------------------------------------------*/
/* Function PROTOTYPES                                                        */
/*----------------------------------------------------------------------------*/
void SysInit(void);
void I2CInit(void);
void Delay(unsigned int num);

/*----------------------------------------------------------------------------*/
/* Global CONSTANTS                                                           */
/*----------------------------------------------------------------------------*/
unsigned char I2C_RW;
unsigned char I2C_TARGET;      // Target I2C slave address
unsigned char I2C_Sendbuf[I2CBufferSize];
unsigned char I2C_Recbuf[I2CBufferSize];
unsigned char I2C_EndFlag;
unsigned int I2C_DataTxLen,I2C_DataTxIndex,I2C_DataRxLen,I2C_DataRxIndex;
unsigned char DisplayBuffer[9];
unsigned char i;
/*----------------------------------------------------------------------------*/
/* Main Function                                                              */
/*----------------------------------------------------------------------------*/
void main(void)
{
	//unsigned char i;
	SysInit();
	I2CInit();

	GIE_Enable();
	while(1)
	{
		LCD_TEST_DISPLAY();		//test LCD display
		ClearLCDframe();				//CLR Display
		DisplayHYcon();					//display show "HYcon"
		Delay(65000);
		ClearLCDframe();			//CLR Display
	}
}

/*----------------------------------------------------------------------------*/
/* Interrupt Service Routines                                                 */
/*----------------------------------------------------------------------------*/
void ISR(void) __interrupt
{
	if(I2CIF_IsFlag() &&I2C_EndFlag==0)  //Get I2C Interrupt Flag
	{
    	switch(I2C_STAState())
    	{
	      case 0x90:  //MACTFlag+RWFlag
	                 //START has been transmitted
	            I2C_SendData(I2C_TARGET);  //Send Slave Address & R/W Bit
	            I2C_Ctrl(0,0,0,0);          //Clear all I2C flag
	            break;

	      case 0x84:  //MACTFlag+ACKFlag
	                 //Slave A + W has been transmitted. ACK has been received.
	            I2C_SendData(I2C_Sendbuf[I2C_DataTxIndex++]);  //Send Data to Slave
	            I2C_Ctrl(0,0,0,0);      //Clear all I2C flag
	            break;

	      case 0x80: //MACTFlag
	                //Slave A + W has been transmitted. ACK has been received.
	      		I2C_SendData(I2C_Sendbuf[I2C_DataTxIndex++]);  //Send Data to Slave
	            I2C_Ctrl(0,0,0,0);      //Clear all I2C flag
	            break;

	      case 0x30:

	            I2C_Ctrl(0,0,0,0);      //Clear all I2C flag
	            I2C_EndFlag=1;
	            break;

	      case 0x8C:  //MACTFlag+DFFlag+ACKFlag
	                //DATA has been transmitted and ACK has been received
	            if(I2C_DataTxIndex<I2C_DataTxLen)
	            {
	              I2C_SendData(I2C_Sendbuf[I2C_DataTxIndex++]);  //Send Data to Slave
	              I2C_Ctrl(0,0,0,0);    // Clear all I2C flag
	            }
	            else
	            {
		            if(I2C_RW == I2C_WRITE)
		            {
		            	I2C_Ctrl(0,1,0,0);  //I2C as master sends STOP signal
		            	I2C_EndFlag=1;
		            }
		            else if(I2C_RW == I2C_READ)
		            I2C_Ctrl(1,0,0,0);  //I2C as master sends START signal
		            I2C_DataTxIndex=0;
	            }
	            break;

	      case 0x88:  //MACTFlag+DFFlag
	                 //DATA has been transmitted and NACK has been received
	            I2C_Ctrl(0,1,0,0);    //I2C as master sends STOP signal
	            I2C_DataTxIndex=0;
	            I2C_EndFlag=1;
	            break;

	      case 0xB0:
	                 //A repeated START has been transmitted.
	            I2C_SendData(I2C_TARGET | I2C_READ);  //Send Slave Address & R/W Bit
	            I2C_Ctrl(0,0,0,0);    //Clear all I2C flag
	            break;

	      case 0x94:  //MACTFlag+RWFlag+ACKFlag
	                 //Slave A + R has been transmitted. ACK has been received.
	            if(I2C_DataRxLen>1)
	            {
	              I2C_Ctrl(0,0,0,1);  //Set ACK bit
	            }else{
	              I2C_Ctrl(0,0,0,0);  //Clear all I2C flag
	            }
	            break;

	      case 0x9C:  //MACTFlag+RWFlag+DFFlag+ACKFlag
	                //Data byte has been received. ACK has been transmitted.
	            I2C_ReceiveDATA(I2C_Recbuf[I2C_DataRxIndex++]);
	           //I2C_Recbuf[I2C_DataRxIndex++]=I2C_ReceiveDATA();
	            if((I2C_DataRxLen-1)>I2C_DataRxIndex)
	            {
	              I2C_Ctrl(0,0,0,1);  //Set ACK bit
	            }
	            else
	            {
	              I2C_Ctrl(0,0,0,0);  //Clear all I2C flag
	            }
	            break;

	      case 0x98:  //MACTFlag+RWFlag+DFFlag
	                //Data byte has been received. NACK has been transmitted.
	            I2C_ReceiveDATA(I2C_Recbuf[I2C_DataRxIndex++]);
	            //I2C_Recbuf[I2C_DataRxIndex++]=I2C_ReceiveDATA();
	            I2C_Ctrl(0,1,0,0);  //I2C as master sends STOP signal
	            I2C_EndFlag=1;
	            break;

	      default:
	            I2C_Ctrl(0,0,0,0);  //Clear all I2C flag
	            I2C_EndFlag=1;
	            break;
    	}
		I2C_I2CINT_CLEAR();		//CLR I2C INT Flag
		I2C_I2CER_CLEAR();		//CLR I2C error Flag
		I2CIF_ClearFlag();				//CLR I2CIF
  	}
  	if(I2CERIF_IsFlag())  //Get I2C Error Interrupt Flag
  	{
	    I2C_EndFlag=1;
		I2C_I2CINT_CLEAR();		//CLR I2C INT Flag
		I2C_I2CER_CLEAR();		//CLR I2C error Flag
		I2CERIF_ClearFlag();		//CLR I2CERIF
	    I2C_Ctrl(0,0,0,0);          //Clear all I2C flag
  	}


}

/*----------------------------------------------------------------------------*/
/* System Init Function                                                          */
/*----------------------------------------------------------------------------*/
void SysInit(void)
{
	//PT1.0 HW Reset Function Ensable
    PT10_HWResetEnable();
	//CPU CLK SELECT
	CLK_CPUCKOpen(HAOM_2MHZ ,OSCS_HAO ,DHS_HSCKDIV1 ,CPUS_DHSCK );  //Please refer to the Datasheet for HAOM center frequency
}

/*----------------------------------------------------------------------------*/
/* I2C Init Function                                                          */
/*----------------------------------------------------------------------------*/
void I2CInit(void)
{
	I2C_Open(50);		//I2C Open

	I2C_SetIOPin(2);	// SCL-> PT3.0  SDA->PT3.1

	I2CIE_Enable();
	I2CERIE_Enable();
}

/*----------------------------------------------------------------------------*/
/* Software Delay Subroutines                                                 */
/*----------------------------------------------------------------------------*/
void Delay(unsigned int num)
{
	for(;num>0;num--)
    __asm__("NOP");
}

/*----------------------------------------------------------------------------*/
/* End Of File                                                                */
/*----------------------------------------------------------------------------*/
