#define  USE_HY17M24_2M
/******************************************************************************
 * Demo_PWR.c                                                        *
 * -------------------------------------------------------------------------- *
 * Copyright 2019 HYCON Technology                                            *
 * http://www.hycontek.com/                                                   *
 *                                                                            *
 * Program Description:                                           *
 *                                                                            *
 *        HY17M24                                                  *
 *--------------------                                                                            *
 *                       |                                                     *
 *                       |                                                     *
 *            PT3.0 |->button1                                                     *
 *            PT3.1 |->button2                                                               *
 *                       |                                                      *
 *                       |                                                     *
 *-------------------                                                     *
 *                                                                            *
 * For External Input                                                         *
 * IC Body: HY17M24                                                           *
 *                                                                                     *
 ******************************************************************************/
/*----------------------------------------------------------------------------*/
/* Includes                                                                   */
/*----------------------------------------------------------------------------*/
#include <SFRType.h>
#include <PWR.h>
#include <GPIO.h>
#include <RST.h>
#include <CLK.h>

/*----------------------------------------------------------------------------*/
/* DEFINITIONS                                                                */
/*----------------------------------------------------------------------------*/
//#define Sleep_mode
#define Idle_mode
/*----------------------------------------------------------------------------*/
/* Function PROTOTYPES                                                        */
/*----------------------------------------------------------------------------*/
void GPIOInit(void);
void Delay(unsigned int num);
/*----------------------------------------------------------------------------*/
/* Global CONSTANTS                                                           */
/*----------------------------------------------------------------------------*/
unsigned char cks=0;
/*----------------------------------------------------------------------------*/
/* Main Function                                                              */
/*----------------------------------------------------------------------------*/
void main(void)
{
    //PT1.0 HW Reset Function Enable
    PT10_HWResetEnable();
////	CPU CLK Init		//
	CLK_OSCSelect(OSCS_LPO);
    CLK_HAODisable();
    CLK_CPUCKSelect(CPUS_DHSCK);

	GPIOInit();

	GIE_Enable();
	while(1)
	{
	    if(GPIO_PT3GET(PT30_H) == 0)
	    {
            Delay(20);		//debounce
	    	while(GPIO_PT3GET(PT30_H) == 0);	//wait PT30=0
            INTE30_Enable();    //PT30 INT Enable
            ENBOR2_Disable();
            PWR_BGRDisable();

            NOP();
            Idle();  //  IDLE mode Enable
            NOP();
	    }

	    if(GPIO_PT3GET(PT31_H) == 0)
	    {
            Delay(20);		//debounce
	    	while(GPIO_PT3GET(PT31_H) == 0);	//wait PT31=0
            INTE31_Enable();    //PT31 INT Enable
            ENBOR2_Disable();
            PWR_BGRDisable();

            NOP();
            Sleep();  //  Sleep mode Enable
            NOP();
	    }
	}
}


/*----------------------------------------------------------------------------*/
/* Interrupt Service Routines                                                 */
/*----------------------------------------------------------------------------*/
void ISR(void) __interrupt
{
	if(INTF30_IsFlag())
	{
		Delay(20);		//debounce
		while(GPIO_PT3GET(PT30_H) == 0);	//wait PT30=0
		INTE30_Disable();
	}

	if(INTF31_IsFlag())
	{
		Delay(20);		//debounce
		while(GPIO_PT3GET(PT31_H) == 0);	//wait PT31=0
		INTE31_Disable();
	}
	INTF30_ClearFlag();
	INTF31_ClearFlag();
}
/*----------------------------------------------------------------------------*/
/* Subroutine Function                                                        */
/*----------------------------------------------------------------------------*/
/*----------------------------------------------------------------------------*/
/*        GPIO Init function                                                           */
/*----------------------------------------------------------------------------*/
void GPIOInit(void)
{
	GPIO_PT3InputEnable(IN30_H | IN31_H);		//PT3.0/3.1 Digital mode
	GPIO_PT3SETPU(PU30_H | PU31_H);
	GPIO_PT3InputMode(TC30_H | TC31_H);			//PT3.0/3.1 Input mode
	INTG30_Edgefall();		//PT30 INT triggering conditions 1->0
	INTE30_Disable();		//PT30 INT Disable
    INTG31_Edgefall();		//PT31 INT triggering conditions 1->0
	INTE31_Disable();		//PT31 INT Disable
}
/*----------------------------------------------------------------------------*/
/* Software Delay Subroutines                                                 */
/*----------------------------------------------------------------------------*/
void Delay(unsigned int num)
{
	for(;num>0;num--)
    __asm__("NOP");
}

/*----------------------------------------------------------------------------*/
/* End Of File                                                                */
/*----------------------------------------------------------------------------*/
