#define  USE_HY17M24_2M
/******************************************************************************
 * PWM.c                                                        *
 * -------------------------------------------------------------------------- *
 * Copyright 2019 HYCON Technology                                            *
 * http://www.hycontek.com/                                                   *
 *                                                                            *
 * Program Description:                                                       *
 *                                                              *
 *   HY17M24                                                                  *
 * -----------                                                                           *
 *           |                                                                 *
 *     PT1.6 |-->PWM0                                                                          *
 *           |                                                                 *
 *     PT1.2 |-->PWM1                                                                      *
 *           |                                                                *
 * -----------                                                                           *
 *                                                                            *
 * For External Input                                                         *
 * IC Body: HY17M24                                                           *

 ******************************************************************************/
/*----------------------------------------------------------------------------*/
/* Includes                                                                   */
/*----------------------------------------------------------------------------*/
#include <SFRType.h>
#include <TMR.h>
#include <CLK.h>
#include <INT.h>
#include <RST.h>
#include <GPIO.h>
/*----------------------------------------------------------------------------*/
/* DEFINITIONS                                                                */
/*----------------------------------------------------------------------------*/
////	Select PWM MODE		//
#define PWM1O
//#define PWM2O
//#define PWM3O
//#define PWM4O
//#define PWM5O
//#define PWM6O
//#define PWM7O

////	Select PWM Output pin	//
#define PT16_PWM0
//#define PT13_PWM0_1
//#define PT32_PWM0_2
#define PT12_PWM1
//#define PT20_PWM1_1
//#define PT33_PWM1_2
/*----------------------------------------------------------------------------*/
/* Function PROTOTYPES                                                        */
/*----------------------------------------------------------------------------*/
void Delay_NOP(unsigned int del);
void CLOCKInit(void);
void TMBInit(void);
void GPIOInit(void);
/*----------------------------------------------------------------------------*/
/* Global CONSTANTS                                                           */
/*----------------------------------------------------------------------------*/
unsigned char tmb_flag=0;
/*----------------------------------------------------------------------------*/
/* Main Function                                                              */
/*----------------------------------------------------------------------------*/
void main(void)
{

    //PT1.0 HW Reset Function Ensable
    PT10_HWResetEnable();

//***** setting cpu clk ********//
    //Please refer to the Datasheet for HAOM center frequency
    CLK_CPUCKOpen(HAOM_2MHZ,OSCS_HAO,DHS_HSCKDIV1,CPUS_DHSCK);

//***** setting GPIO  *********//
    GPIOInit();

//***** setting the timer B & PWM *********//
/*--------------------------------------PWM1O-------------------------------------------*/
#ifdef PWM1O
	TMB_Open(TMBS_HSCK ,DTMB_TMBCKDIV1 ,TB1M_16bit ,TB1RT_LogicH );

	TB1_PWM0_PHASE(PA0IV_NORMAL);		//PWM0 Output Phase Normal
	TB1_PWM1_PHASE(PA1IV_INVER);		//PWM1 Output Phase Normal

	TB1_PWM0ModeSelect(PWMA0_PWM1O);		//PWM0 Output mode Select PWM1O
	TB1_PWM1ModeSelect(PWMA1_PWM1O);		//PWM1 Output mode Select PWM1O

	TB1_PWMO0(PWMO0_OUTPUT);				//PWM0 Enable
	TB1_PWMO1(PWMO1_OUTPUT);				//PWM1 Enable

	TB1C0Set(0x0800);	// TB1C0[15:0] is setting the PWM frequency.
	TB1C1Set(0x0400);	// TB1C1[15:0] is setting the PWM Duty Cycle.
#endif

/*--------------------------------------PWM2O-------------------------------------------*/
#ifdef PWM2O
	TMB_Open(TMBS_HSCK ,DTMB_TMBCKDIV1 ,TB1M_16bit ,TB1RT_LogicH );

	TB1_PWM0_PHASE(PA0IV_NORMAL);		//PWM0 Output Phase Normal
	TB1_PWM1_PHASE(PA1IV_INVER);		//PWM1 Output Phase Normal

	TB1_PWM0ModeSelect(PWMA0_PWM2O);		//PWM0 Output mode Select PWM2O
	TB1_PWM1ModeSelect(PWMA1_PWM2O);		//PWM1 Output mode Select PWM2O

	TB1_PWMO0(PWMO0_OUTPUT);				//PWM0 Enable
	TB1_PWMO1(PWMO1_OUTPUT);				//PWM1 Enable

	TB1C0Set(0x0833);	//TB1C0[15:0] is setting the PWM frequency.
	TB1C2Set(0x01a4);	// TB1C2[15:0] is setting the PWM Duty Cycle.
#endif

/*--------------------------------------PWM3O-------------------------------------------*/
#ifdef PWM3O
	TMB_Open(TMBS_HSCK ,DTMB_TMBCKDIV1 ,TB1M_2_8bit ,TB1RT_LogicH );

	TB1_PWM0_PHASE(PA0IV_NORMAL);		//PWM0 Output Phase Normal
	TB1_PWM1_PHASE(PA1IV_INVER);		//PWM1 Output Phase Normal

	TB1_PWM0ModeSelect(PWMA0_PWM3O);		//PWM0 Output mode Select PWM3O
	TB1_PWM1ModeSelect(PWMA1_PWM3O);		//PWM1 Output mode Select PWM3O

	TB1_PWMO0(PWMO0_OUTPUT);				//PWM0 Enable
	TB1_PWMO1(PWMO1_OUTPUT);				//PWM1 Enable

	TB1C0Set(0x0029);	// TB1C0L[7:0] is setting the PWM frequency.
	TB1C1Set(0x0016);	// TB1C0L[7:0] is setting the PWM Duty Cycle.
#endif

/*--------------------------------------PWM4O-------------------------------------------*/
#ifdef PWM4O
	TMB_Open(TMBS_HSCK ,DTMB_TMBCKDIV1 ,TB1M_2_8bit ,TB1RT_LogicH );

	TB1_PWM0_PHASE(PA0IV_NORMAL);		//PWM0 Output Phase Normal
	TB1_PWM1_PHASE(PA1IV_INVER);		//PWM1 Output Phase Normal

	TB1_PWM0ModeSelect(PWMA0_PWM4O);		//PWM0 Output mode Select PWM4O
	TB1_PWM1ModeSelect(PWMA1_PWM4O);		//PWM1 Output mode Select PWM4O

	TB1_PWMO0(PWMO0_OUTPUT);				//PWM0 Enable
	TB1_PWMO1(PWMO1_OUTPUT);				//PWM1 Enable

	TB1C0Set(0xD100);	// TB1C0H[15:8] is setting the PWM frequency.
	TB1C2Set(0x0088);	// TB1C2L[7:0] is setting the PWM Duty Cycle.
#endif

/*--------------------------------------PWM5O-------------------------------------------*/
#ifdef PWM5O
	TMB_Open(TMBS_HSCK ,DTMB_TMBCKDIV1 ,TB1M_8_8bit ,TB1RT_LogicH );

	TB1_PWM0_PHASE(PA0IV_NORMAL);		//PWM0 Output Phase Normal
	TB1_PWM1_PHASE(PA1IV_INVER);		//PWM1 Output Phase Normal

	TB1_PWM0ModeSelect(PWMA0_PWM5O);		//PWM0 Output mode Select PWM5O
	TB1_PWM1ModeSelect(PWMA1_PWM5O);		//PWM1 Output mode Select PWM5O

	TB1_PWMO0(PWMO0_OUTPUT);				//PWM0 Enable
	TB1_PWMO1(PWMO1_OUTPUT);				//PWM1 Enable

	TB1C0Set(0x00C8);	// TB1C0L[7:0] is setting the PWM frequency.
	TB1C1Set(0x0064);	// TB1C1L[7:0] is setting the PWM Duty Cycle.
	TB1C2Set(0x0080);	//	TB1C2L[7:0] is setting the PWM Duty Cycle fine tuning.
#endif

/*--------------------------------------PWM6O-------------------------------------------*/
#ifdef PWM6O
	TMB_Open(TMBS_HSCK ,DTMB_TMBCKDIV1 ,TB1M_17bit ,TB1RT_LogicH );

	TB1_PWM0_PHASE(PA0IV_NORMAL);		//PWM0 Output Phase Normal
	TB1_PWM1_PHASE(PA1IV_INVER);		//PWM1 Output Phase Normal

	TB1_PWM0ModeSelect(PWMA0_PWM6O);		//PWM0 Output mode Select PWM6O
	TB1_PWM1ModeSelect(PWMA1_PWM6O);		//PWM1 Output mode Select PWM6O

	TB1_PWMO0(PWMO0_OUTPUT);				//PWM0 Enable
	TB1_PWMO1(PWMO1_OUTPUT);				//PWM1 Enable

	TB1C0Set(0x0002);	// TB1C0L[7:0] is setting the PWM frequency.
	TB1C1Set(0x0001);	// TB1C1L[7:0] is setting the PWM Duty Cycle.
	TB1C2Set(0x0080);	//	TB1C2L[7:0] is setting the PWM Duty Cycle
									// TB1C0 > TB1C2 > TB1C1
#endif

/*--------------------------------------PWM7O-------------------------------------------*/
#ifdef PWM7O
	TMB_Open(TMBS_HSCK ,DTMB_TMBCKDIV1 ,TB1M_16bit ,TB1RT_LogicH );

	TB1_PWM0_PHASE(PA0IV_NORMAL);		//PWM0 Output Phase Normal
	TB1_PWM1_PHASE(PA1IV_INVER);		//PWM1 Output Phase Normal

	TB1_PWM0ModeSelect(PWMA0_PWM7O);		//PWM0 Output mode Select PWM7O
	TB1_PWM1ModeSelect(PWMA1_PWM7O);		//PWM1 Output mode Select PWM7O

	TB1_PWMO0(PWMO0_OUTPUT);				//PWM0 Enable
	TB1_PWMO1(PWMO1_OUTPUT);				//PWM1 Enable

	TB1C0Set(0x1FFF);	// TB1C0[15:0] is setting the PWM frequency.
										// PWM Duty Cycle is always 50%
#endif

	TB1_ClearTMB1();	//TMB COUNT CLR
	TB1Enable();

	while(1);

}
/*----------------------------------------------------------------------------*/
/* Subroutine Function                                                        */
/*----------------------------------------------------------------------------*/
void GPIOInit(void)
{
#ifdef PT16_PWM0
	GPIO_PT1InputEnable(PT16_H);				//PT16 Digital mode
	GPIO_PT1OutputMode(PT16_H);			//PT16 Output mode
	GPIO_PT1OutputLow(PT16_MSK);		//PT16 Output Low
	GPIO_PM16Sel(PM16_PWM0);			//PT16 PWM0 Enable
#endif

#ifdef PT13_PWM0_1
	GPIO_PT1InputEnable(PT13_H);				//PT13 Digital mode
	GPIO_PT1OutputMode(PT13_H);			//PT13 Output mode
	GPIO_PT1OutputLow(PT13_MSK);		//PT13 Output Low
	GPIO_PM13Sel(PM13_PWM0_1);			//PT13 PWM0_1 Enable
#endif

#ifdef PT32_PWM0_2
	GPIO_PT3InputEnable(PT32_H);				//PT32 Digital mode
	GPIO_PT3OutputMode(PT32_H);			//PT32 Output mode
	GPIO_PT3OutputLow(PT32_MSK);		//PT32 Output Low
	GPIO_PM32Sel(PM32_PWM0_2);		//PT32 PWM0_2 Enable
#endif

#ifdef PT12_PWM1
	GPIO_PT1InputEnable(PT12_H);				//PT12 Digital mode
	GPIO_PT1OutputMode(PT12_H);			//PT12 Output mode
	GPIO_PT1OutputLow(PT12_MSK);		//PT12 Output Low
	GPIO_PM12Sel(PM12_PWM1);			//PT12 PWM1 Enable
#endif

#ifdef PT20_PWM1_1
	GPIO_PT2InputEnable(PT20_H);				//PT20 Digital mode
	GPIO_PT2OutputMode(PT20_H);			//PT20 Output mode
	GPIO_PT2OutputLow(PT20_MSK);		//PT20 Output Low
	GPIO_PM20Sel(PM20_PWM1_1);			//PT20 PWM1_1 Enable
#endif

#ifdef PT33_PWM1_2
	GPIO_PT3InputEnable(PT33_H);				//PT33 Digital mode
	GPIO_PT3OutputMode(PT33_H);			//PT33 Output mode
	GPIO_PT3OutputLow(PT33_MSK);		//PT33 Output Low
	GPIO_PM33Sel(PM33_PWM1_2);		//PT33 PWM1_2 Enable
#endif


}
/*----------------------------------------------------------------------------*/
/* End Of File                                       */
/*----------------------------------------------------------------------------*/

