#define  USE_HY17M24_2M
/******************************************************************************
 * TMB.c                                                        *
 * -------------------------------------------------------------------------- *
 * Copyright 2019 HYCON Technology                                            *
 * http://www.hycontek.com/                                                   *
 *                                                                            *
 * Program Description:                                                       *
 *                                                                            *
 * For External Input                                                         *
 * IC Body: HY17M24                                                           *

 ******************************************************************************/
/*----------------------------------------------------------------------------*/
/* Includes                                                                   */
/*----------------------------------------------------------------------------*/
#include <SFRType.h>
#include <TMR.h>
#include <CLK.h>
#include <INT.h>
#include <GPIO.h>
#include <PWR.h>
#include <RST.h>
/*----------------------------------------------------------------------------*/
/* DEFINITIONS                                                                */
/*----------------------------------------------------------------------------*/
#define mode_16bit
//#define mode_17bit
//#define mode_2_8bit
//#define mode_8_8bit
/*----------------------------------------------------------------------------*/
/* Function PROTOTYPES                                                        */
/*----------------------------------------------------------------------------*/
void Delay_NOP(unsigned int del);
void CLOCKInit(void);
void TMBInit(void);
void GPIOInit(void);
/*----------------------------------------------------------------------------*/
/* Global CONSTANTS                                                           */
/*----------------------------------------------------------------------------*/
unsigned char tmb_flag=0;
/*----------------------------------------------------------------------------*/
/* Main Function                                                              */
/*----------------------------------------------------------------------------*/
void main(void)
{
    PT10_HWResetEnable();	//PT1.0 HW Reset Function Ensable

/*******System Init************/
	CLOCKInit();
	TMBInit();
	GPIOInit();

	GIE_Enable();
	while(1);
}

/*----------------------------------------------------------------------------*/
/* Interrupt Service Routines                                                 */
/*----------------------------------------------------------------------------*/
void ISR(void) __interrupt
{
	if(TMBIF_IsFlag())		//TB1R=TB1C ,TMBIF=1
	{
		tmb_flag=~tmb_flag;
		if(tmb_flag)
		GPIO_PT3OutputHigh(PT33_H);
		else
		GPIO_PT3OutputLow(PT33_MSK);
		TMBIF_ClearFlag();
	}
}

/*----------------------------------------------------------------------------*/
/* Subroutine Function                                                        */
/*----------------------------------------------------------------------------*/
void Delay_NOP(unsigned int del)
{
  while(--del)
  NOP();
}

/*----------------------------------------------------------------------------*/
/* TMB Init Function                                                        */
/*----------------------------------------------------------------------------*/
void TMBInit(void)		//select TMB mode
{
#ifdef mode_16bit
	TMB_Open(TMBS_HSCK ,DTMB_TMBCKDIV2 ,TB1M_16bit ,TB1RT_LogicH );
	TB1C0Set(0x00ff);	//Set TMB count
#endif


#ifdef mode_17bit
	TMB_Open(TMBS_HSCK ,DTMB_TMBCKDIV2 ,TB1M_17bit ,TB1RT_LogicH );
	TB1C0Set(0x7fff);	//Set TMB count
#endif


#ifdef mode_2_8bit
	TMB_Open(TMBS_HSCK ,DTMB_TMBCKDIV2 ,TB1M_2_8bit ,TB1RT_LogicH );
	TB1C0Set(0x7fff);	//Set TMB count
#endif


#ifdef mode_8_8bit
	TMB_Open(TMBS_HSCK ,DTMB_TMBCKDIV2 ,TB1M_8_8bit ,TB1RT_LogicH );
	TB1C0Set(0x7fff);	//Set TMB count
#endif

	TB1Enable();
}



/*----------------------------------------------------------------------------*/
/* CLOCK Init Function                                                        */
/*----------------------------------------------------------------------------*/
void CLOCKInit(void)
{
    //Please refer to the Datasheet for HAOM center frequency
	CLK_CPUCKOpen(HAOM_2MHZ ,OSCS_HAO ,DHS_HSCKDIV1 ,CPUS_DHSCK );
}

/*----------------------------------------------------------------------------*/
/* GPIO Init Function                                                        */
/*----------------------------------------------------------------------------*/
void GPIOInit(void)
{
	GPIO_PT3InputEnable(PT33_MSK);	//PT33 Digital mode
	GPIO_PT3OutputMode(PT33_H);			//PT33 Output mode
	GPIO_PT3OutputLow(PT33_MSK);		//PT33 Output Low
}

/*----------------------------------------------------------------------------*/
/* End Of File                                                                */
/*----------------------------------------------------------------------------*/
